@@ -47,7 +47,7 @@ static int zuluCryptEXEGetDevice( const char * device )
 	zuluCryptSecurityDropElevatedPrivileges() ;
 
 	if( c == NULL ){
-		printf( gettext( "ERROR: could not get device address from mapper address\n" ) ) ;
+		printf( gettext( "ERROR: Could not get device address from mapper address\n" ) ) ;
 		st = 1 ;
 	}else{
 		printf( "%s\n",c ) ;
@@ -71,9 +71,9 @@ static int zuluCryptEXECheckIfLuks( const char * device )
 	zuluCryptSecurityDropElevatedPrivileges() ;
 
 	if( status ){
-		printf( gettext( "device is a luks volume\n" ) ) ;
+		printf( gettext( "Device is a luks volume\n" ) ) ;
 	}else{
-		printf( gettext( "device is not a luks volume\n" ) ) ;
+		printf( gettext( "Device is not a luks volume\n" ) ) ;
 	}
 	return status ;
 }
@@ -87,11 +87,11 @@ static int zuluCryptEXECheckIfTcrypt( struct_opts * clargs,uid_t uid )
 	size_t key_len ;
 	int st = 1 ;
 	if( key == NULL ){
-		printf( gettext( "ERROR: key argument is missing\n" ) ) ;
+		printf( gettext( "ERROR: Key argument is missing\n" ) ) ;
 		return 1 ;
 	}
 	if( source == NULL ){
-		printf( gettext( "ERROR: key source argument is missing\n" ) ) ;
+		printf( gettext( "ERROR: Key source argument is missing\n" ) ) ;
 		return 1 ;
 	}
 	if( StringsAreEqual( source,"-p" ) ){
@@ -148,7 +148,7 @@ static int zuluCryptEXECheckEmptySlots( const char * device )
 	zuluCryptSecurityDropElevatedPrivileges() ;
 
 	if( c == NULL ){
-		printf( gettext( "device \"%s\" is not a luks device\n" ),device ) ;
+		printf( gettext( "Device \"%s\" is not a luks device\n" ),device ) ;
 		status = 2 ;
 	}else{
 		printf( "%s\n",c ) ;
@@ -174,7 +174,7 @@ static int zuluCryptEXEHeaderMatchBackUpHeader( const char * device,const char *
 
 	if( r == 1 ){
 		if( uid != 0 || !zuluCryptUserIsAMemberOfAGroup( uid,"zulucrypt" ) ){
-			printf( gettext( "ERROR: insufficient privilges to operate on a system device\n" ) ) ;
+			printf( gettext( "ERROR: Insufficient privilges to operate on a system device\n" ) ) ;
 			return 1 ;
 		}
 	}
@@ -183,10 +183,10 @@ static int zuluCryptEXEHeaderMatchBackUpHeader( const char * device,const char *
 	 */
 	r = zuluCryptHeaderMatchBackUpHeader( device,header_backup,uid ) ;
 	if( r ){
-		printf( gettext( "header backup match the one on the device\n" ) ) ;
+		printf( gettext( "Header backup match the one on the device\n" ) ) ;
 		return 0 ;
 	}else{
-		printf( gettext( "header backup does not match the one on the device\n" ) ) ;
+		printf( gettext( "Header backup does not match the one on the device\n" ) ) ;
 		return 1 ;
 	}
 }
@@ -218,7 +218,7 @@ static int zuluCryptEXE( struct_opts * clargs,const char * mapping_name,uid_t ui
 	return 200 ; /* shouldnt get here */
 }
 
-static int zuluExit( int st,stringList_t stl,stringList_t stx,const char * const * env,const char * msg )
+static int zuluExit( int st,stringList_t stl,stringList_t stx,char * const * env,const char * msg )
 {
 	zuluCryptSecurityUnlockMemory( stl ) ;
 	StringListClearDelete( &stl ) ;
@@ -235,7 +235,7 @@ static int zuluExit( int st,stringList_t stl,stringList_t stx,const char * const
 
 static void ExitOnMemoryExaustion( void )
 {
-	printf( gettext( "unexpected exiting because you have run out of memory\n" ) ) ;
+	printf( gettext( "Unexpected exiting because you have run out of memory\n" ) ) ;
 	exit( 1 ) ;
 }
 
@@ -270,6 +270,9 @@ static void _forceTerminateOnSeriousError( int sig )
 
 static int _clear_dead_mappers( uid_t uid )
 {
+	/*
+	 * zuluCryptClearDeadMappers() is defined in ../zuluCrypt-cli/bin/clear_dead_mappers.c
+	 */
 	zuluCryptClearDeadMappers( uid ) ;
 	return 0 ;
 }
@@ -299,18 +302,18 @@ int main( int argc,char * argv[] )
 	char * dev ;
 	char action ;
 	int st ;
-	const char * const * env ;
+	char * const * env = NULL ;
 	ssize_t i ;
 
 	string_t q = StringVoid ;
 
-	stringList_t stl ;
-	stringList_t stx ;
+	stringList_t stl = StringListVoid ;
+	stringList_t stx = StringListVoid ;
 
 	struct_opts clargs ;
 
 	uid_t uid = getuid() ;
-	gid_t gid = getgid() ;
+	gid_t gid = uid ;
 
 	struct sigaction sa ;
 	memset( &sa,'\0',sizeof( struct sigaction ) ) ;
@@ -337,7 +340,27 @@ int main( int argc,char * argv[] )
 
 	setlocale( LC_ALL,"" );
 	bindtextdomain( "zuluCrypt-cli",TRANSLATION_PATH ) ;
-	textdomain( "zuluCrypt-cli" );
+	textdomain( "zuluCrypt-cli" ) ;
+
+	memset( &clargs,'\0',sizeof( struct_opts ) ) ;
+
+	/*
+	 * zuluCryptEXEGetOpts() is defined in ./get_opts.c
+	 */
+	zuluCryptEXEGetOpts( argc,argv,&clargs ) ;
+
+	/*
+	 * zuluCryptSecurityConvertUID() is defined in security.c
+	 */
+	st = zuluCryptSecurityConvertUID( uid,clargs.uid ) ;
+
+	if( st == -1 ){
+
+		printf( gettext( "User is not root\n" ) ) ;
+		return 114 ;
+	}else{
+		uid = st ;
+	}
 
 	/*
 	 * Run with higher priority to speed things up
@@ -347,18 +370,16 @@ int main( int argc,char * argv[] )
 	setuid( 0 ) ;
 	seteuid( uid ) ;
 
-	/*
-	 * zuluCryptSecuritySetPrivilegeElevationErrorFunction() is defined in ./security.c
-	 * _privilegeEvelationError() function will be called when functions that elevate or drop privilges fail
-	 */
-	zuluCryptSecuritySetPrivilegeElevationErrorFunction( _privilegeEvelationError ) ;
-
 	/*
 	 * zuluCryptSetUserUIDForPrivilegeManagement() is defined in ./security.c
 	 */
 	zuluCryptSetUserUIDForPrivilegeManagement( uid ) ;
 
-	memset( &clargs,'\0',sizeof( struct_opts ) ) ;
+	/*
+	 * zuluCryptSecuritySetPrivilegeElevationErrorFunction() is defined in ./security.c
+	 * _privilegeEvelationError() function will be called when functions that elevate or drop privilges fail
+	 */
+	zuluCryptSecuritySetPrivilegeElevationErrorFunction( _privilegeEvelationError ) ;
 
 	StringExitOnMemoryExaustion( ExitOnMemoryExaustion ) ;
 	StringListExitOnMemoryExaustion( ExitOnMemoryExaustion ) ;
@@ -386,11 +407,6 @@ int main( int argc,char * argv[] )
 		}
 	}
 
-	/*
-	 * zuluCryptEXEGetOpts() is defined in ./get_opts.c
-	 */
-	zuluCryptEXEGetOpts( argc,argv,&clargs );
-
 	/*
 	 * this object is used as a form of memory management.It collects all string objects to make them easily deletable
 	 * at the end of the function and allows a function to have easily managebale multiple exit points.
@@ -421,7 +437,7 @@ int main( int argc,char * argv[] )
 		StringSubChar( q,StringLength( q ) - 1,'\0' ) ;
 	}
 
-	clargs.argv = StringListContentAt( stl,0 );
+	clargs.argv = StringListContentAtFirstPlace( stl ) ;
 
 	/*
 	 * Hide "sensitive" command line arguments from ps comamnd and related tools.
@@ -472,7 +488,7 @@ int main( int argc,char * argv[] )
 	/*
 	 * below tests are here because they do not use -d option
 	 *
-	 * zuluCryptPrintPartitions() function is defined in partitions.c
+	 * zuluCryptPrintPartitions() function is defined in volumes.c
 	 * zuluCryptSecurityCheckPartitionPermissions() is defined in security.c
 	 */
 	switch( action ){
@@ -485,16 +501,13 @@ int main( int argc,char * argv[] )
 			  return zuluExit( st,stl,stx,env,NULL ) ;
 	}
 
-	/*
-	 * zuluCryptClearDeadMappers() is defined in clear_dead_mapper.c
-	 */
-	zuluCryptClearDeadMappers( uid ) ;
+	_clear_dead_mappers( uid ) ;
 
 	if( action == '\0' ){
 		return zuluExit( 130,stl,stx,env,gettext( "ERROR: \"action\" argument is missing" ) ) ;
 	}
 	if( device == NULL ){
-		return zuluExit( 120,stl,stx,env,gettext( "ERROR: required option( device path ) is missing for this operation" ) ) ;
+		return zuluExit( 120,stl,stx,env,gettext( "ERROR: Required option( device path ) is missing for this operation" ) ) ;
 	}
 	if( action == 'U' ){
 		st = _print_uuid_from_path( device ) ;
@@ -516,12 +529,12 @@ int main( int argc,char * argv[] )
 		if( ac != NULL ) {
 			clargs.device = ac ;
 			st = zuluCryptEXE( &clargs,mapping_name,uid ) ;
-			free( ac ) ;
+			StringFree( ac ) ;
 			StringDelete( &q ) ;
 			return zuluExit( st,stl,stx,env,NULL ) ;
 		}else{
 			StringDelete( &q ) ;
-			return zuluExit( 110,stl,stx,env,gettext( "ERROR: could not find any partition with the presented UUID" ) ) ;
+			return zuluExit( 110,stl,stx,env,gettext( "ERROR: Could not find any partition with the presented UUID" ) ) ;
 		}
 	}else{
 		/*
@@ -529,11 +542,11 @@ int main( int argc,char * argv[] )
 		 */
 		switch( zuluCryptGetDeviceFileProperties( device,&fd,&fd1,&dev,uid ) ){
 			case 0 : break ;
-			case 1 : return zuluExit( 111,stl,stx,env,gettext( "ERROR: devices in /dev/shm/ path is not suppored" ) ) ;
-			case 2 : return zuluExit( 112,stl,stx,env,gettext( "ERROR: given path is a directory" ) ) ;
-			case 3 : return zuluExit( 113,stl,stx,env,gettext( "ERROR: a file can have only one hard link" ) ) ;
-			case 4 : return zuluExit( 113,stl,stx,env,gettext( "ERROR: insufficient privilges to access the device" ) ) ;
-			default: return zuluExit( 113,stl,stx,env,gettext( "ERROR: a non supported device encountered,device is missing or permission denied\n\
+			case 1 : return zuluExit( 111,stl,stx,env,gettext( "ERROR: Devices in /dev/shm/ path is not suppored" ) ) ;
+			case 2 : return zuluExit( 112,stl,stx,env,gettext( "ERROR: Given path is a directory" ) ) ;
+			case 3 : return zuluExit( 113,stl,stx,env,gettext( "ERROR: A file can have only one hard link" ) ) ;
+			case 4 : return zuluExit( 113,stl,stx,env,gettext( "ERROR: Insufficient privilges to access the device" ) ) ;
+			default: return zuluExit( 113,stl,stx,env,gettext( "ERROR: A non supported device encountered,device is missing or permission denied\n\
 Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The device has LVM or MDRAID signature" ) ) ;
 		}
 
@@ -544,7 +557,7 @@ Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The de
 			if( fd != -1 ){
 				close( fd ) ;
 			}
-			return zuluExit( 114,stl,stx,env,gettext( "ERROR: could not resolve path to device" ) ) ;
+			return zuluExit( 114,stl,stx,env,gettext( "ERROR: Could not resolve path to device" ) ) ;
 		}else{
 			/*
 			 * zuluCryptDeviceIsSupported() is defined in partitions.c
@@ -577,7 +590,7 @@ Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The de
 				}
 			}else{
 				st = 113 ;
-				puts( gettext( "ERROR: a non supported device encountered,device is missing or permission denied\n\
+				puts( gettext( "ERROR: A non supported device encountered,device is missing or permission denied\n\
 Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The device has LVM or MDRAID signature" ) ) ;
 			}
 
