@@ -17,39 +17,70 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "includes.h"
-
-/*
- * this header is created at config time
- */
-#include "truecrypt_support.h"
-#include <libcryptsetup.h>
 #include <unistd.h>
+#include <stddef.h>
+#include <libcryptsetup.h>
+#include "includes.h"
+#include "tcplay_support.h"
+
+static int _close_mapper( const char * mapper,int TrueCryptOrVeraCryptVolume )
+{
+	int r = 1 ;
+
+	struct crypt_device * cd ;
+
+	tc_api_task task ;
+
+	if( TrueCryptOrVeraCryptVolume ){
+
+		if( tc_api_initialize() ){
+
+			task = tc_api_task_init( "unmap" ) ;
+
+			if( tc_api_task_initialized( task ) ){
+
+				mapper = mapper + StringLastIndexOfChar_1( mapper,'/' ) + 1 ;
+
+				tc_api_task_set( task,"map_name",mapper ) ;
+
+				r = tc_api_task_do( task ) ;
+
+				tc_api_task_uninit( task ) ;
+			}
+
+			tc_api_uninit() ;
+		}
+	}else{
+		if( crypt_init_by_name( &cd,mapper ) == 0 ){
+
+			r = crypt_deactivate( cd,mapper ) ;
+
+			crypt_free( cd ) ;
+		}
+	}
+
+	return r ;
+}
 
 int zuluCryptCloseMapper( const char * mapper )
 {
-	int j ;
-	int st = 1;
-	struct crypt_device * cd;
-	if( crypt_init_by_name( &cd,mapper ) == 0 ){
-		for( j = 0 ; j < 3 ; j++ ) {
-			/*
-			* try multiple types to close the mapper just in case
-			*/
-			st = crypt_deactivate( cd,mapper ) ;
-			if( st == 0 ){
-				break ;
-			}else{
-				sleep( 1 ) ;
-			}
+	int i ;
+
+	/*
+	 * zuluCryptTrueCryptOrVeraCryptVolume() is defined in status.c
+	 */
+	int e = zuluCryptTrueCryptOrVeraCryptVolume( mapper ) ;
+
+	for( i = 0 ; i < 3 ; i++ ){
+
+		if( _close_mapper( mapper,e ) == 0 ){
+
+			return 0 ;
+		}else{
+			sleep( 1 ) ;
 		}
-		crypt_free( cd ) ;
-	}else{
-		/*
-		 * we shouldnt get here
-		 */
-		;
+
 	}
 
-	return st ;
+	return 1 ;
 }
