@@ -64,18 +64,20 @@ struct StringType
 	int owned ;
 };
 
-static void ( *_fcn_ )( void )  = NULL ;
+static void _f( void )
+{
+}
+
+static void ( *_memory_error )( void )  = _f ;
 
 void StringExitOnMemoryExaustion( void ( *f )( void ) )
 {
-	_fcn_ = f ;
+	_memory_error = f ;
 }
 
 static void * _StringError( void )
 {
-	if( _fcn_ != NULL ){
-		( *_fcn_ )() ;
-	}
+	_memory_error() ;
 	return NULL ;
 }
 
@@ -759,15 +761,52 @@ char * StringCopy_3( string_t st,size_t l )
 	}
 }
 
+static int _string_ends_with( const char * e,size_t ee,const char * s,size_t ss )
+{
+	if( ee >= ss ){
+		return memcmp( e + ee - ss,s,ss ) == 0 ;
+	}else{
+		return 0 ;
+	}
+}
+
 int StringEndsWith( string_t st,const char * s )
 {
-	size_t j ;
-
 	if( st == StringVoid || s == NULL ){
 		return 0 ;
 	}else{
-		j = strlen( s ) ;
-		return strncmp( st->string + st->size - j,s,j ) == 0 ;
+		return _string_ends_with( st->string,st->size,s,strlen( s ) ) ;
+	}
+}
+
+int StringEndsWith_1( const char * e,const char * s )
+{
+	if( e == NULL || s == NULL ){
+		return 0 ;
+	}else{
+		return _string_ends_with( e,strlen( e ),s,strlen( s ) ) ;
+	}
+}
+
+int StringEndsWith_2( string_t e,string_t s )
+{
+	if( e == StringVoid || s == StringVoid ){
+		return 0 ;
+	}else{
+		return _string_ends_with( e->string,e->size,s->string,s->size ) ;
+	}
+}
+
+int StringStartsAndEndsWith( const char * a,const char * b,const char * c )
+{
+	if( a == NULL || b == NULL || c == NULL ){
+		return 0 ;
+	}else{
+		if( strncmp( a,b,strlen( b ) ) == 0 ){
+			return _string_ends_with( a,strlen( a ),c,strlen( c ) ) ;
+		}else{
+			return 0 ;
+		}
 	}
 }
 
@@ -791,7 +830,7 @@ int StringStartsWith_1( string_t st,string_t xt )
 
 int StringEndsWithChar( string_t st,char s )
 {
-	if( st == StringVoid ){
+	if( st == StringVoid || st->size < 1 ){
 		return 0 ;
 	}else{
 		return st->string[ st->size - 1 ] == s ;
@@ -939,7 +978,10 @@ const char * StringReplace( string_t st,const char * s )
 	size_t len ;
 	char * c   ;
 
-	if( st == StringVoid || s == NULL ){
+	if( st == StringVoid ){
+		return s ;
+	}
+	if( s == NULL ){
 		return NULL ;
 	}else{
 		len = strlen( s ) ;
@@ -1251,6 +1293,15 @@ const char * StringRemoveString( string_t st,const char * s )
 	return StringRemoveStringPos( st,s,0 ) ;
 }
 
+int StringIsEmpty( string_t x )
+{
+	if( x == StringVoid ){
+		return 0 ;
+	}else{
+		return x->string[ 0 ] == '\0' ;
+	}
+}
+
 static char * StringCRC__( string_t st, char x,char y,size_t p )
 {
 	char * c ;
@@ -1269,7 +1320,6 @@ static char * StringCRC__( string_t st, char x,char y,size_t p )
 	return st->string ;
 }
 
-
 const char * StringReplaceCharPos( string_t st,char x,char y,size_t p )
 {
 	return StringCRC__( st,x,y,p ) ;
