@@ -368,14 +368,32 @@ int StringLock( string_t ) ;
 int StringUnlock( string_t ) ;
 
 /*
- *Check to see if the string pointer by st ends with string s.
+ * Check to see if the string pointer by st ends with string s.
  *
  * return 1 is it does
  *
- * return 0 if it doesnt *
+ * return 0 if it doesnt
  */
 int StringEndsWith( string_t st,const char * s ) ;
 
+/*
+ * Check to see if a string e ends with string s.
+ *
+ * return 1 is it does
+ *
+ * return 0 if it doesnt
+ */
+int StringEndsWith_1( const char * e,const char * s ) ;
+
+/*
+ * Check to see if a string e ends with a string s.
+ *
+ * return 1 is it does
+ *
+ * return 0 if it doesnt
+ */
+int StringEndsWith_2( string_t e,string_t s ) ;
+
 /*
  * check to see if the string handled by handle st starts with a string s
  * return 1 if it does
@@ -390,6 +408,13 @@ int StringStartsWith( string_t st,const char * s ) ;
  */
 int StringStartsWith_1( string_t st,string_t xt ) ;
 
+/*
+ * check if string a starts with string b and ends with string c
+ * return 1 if it does
+ * return 0 if it doesnt
+ */
+int StringStartsAndEndsWith( const char * a,const char * b,const char * c ) ;
+
 /*
  * check to see the string_t object starts with atleast one of the arbitrary number of cstrings
  * return 1 if it does
@@ -592,6 +617,13 @@ int StringEqualString( string_t x,string_t y ) ;
  */
 int StringEqual( string_t x,const char * y ) ;
 
+/*
+ * return 1 if x holds an empty string
+ * return 0 if x holds a non empty string
+ * return 0 if x is StringVoid
+ */
+int StringIsEmpty( string_t x ) ;
+
 /*
  * Compare a string handled by handle x to a string pointer to by y.
  * return 0 if they are equal
@@ -805,6 +837,11 @@ static __inline__ int StringsAreEqual( const char * x,const char * y )
 	}
 }
 
+static __inline__ int StringHasNothing( const char * x )
+{
+	return x != NULL && *x == '\0' ;
+}
+
 static __inline__ int StringsAreNotEqual( const char * x,const char * y )
 {
 	if( x == NULL || y == NULL ){
@@ -907,22 +944,22 @@ static __inline__ ssize_t StringLastIndexOfChar_1( const char * str,char s )
 	}
 }
 
-static __inline__ const char * StringContent( string_t st )
-{
-	const char ** e ;
-	if( st == StringVoid ){
-		return NULL ;
-	}else{
-		e = ( const char ** )st ;
-		return *e ;
-	}
-}
-
 static __inline__ const char ** StringPointer( string_t st )
 {
 	return ( const char ** ) st ;
 }
 
+static __inline__ const char * StringContent( string_t st )
+{
+	const char ** e = StringPointer( st ) ;
+
+	if( e == NULL ){
+		return NULL ;
+	}else{
+		return *e ;
+	}
+}
+
 #ifdef __cplusplus
 }
 #endif
