@@ -45,18 +45,20 @@ struct StringType
 	int owned ;
 };
 
-static void ( *_fcn_ )( void )  = NULL ;
+static void _f( void )
+{
+}
+
+static void ( *_memory_error )( void )  = _f ;
 
 void StringListExitOnMemoryExaustion( void ( *f )( void ) )
 {
-	_fcn_ = f ;
+	_memory_error = f ;
 }
 
 static void * _StringListError( void )
 {
-	if( _fcn_ != NULL ){
-		(*_fcn_)() ;
-	}
+	_memory_error() ;
 	return NULL ;
 }
 
@@ -907,7 +909,7 @@ string_t StringListHasStartSequence_1( stringList_t stl,const char * str )
 	}
 }
 
-const char * const * StringListStringArray( stringList_t stl )
+char * const * StringListStringArray( stringList_t stl )
 {
 	size_t i ;
 	size_t j ;
@@ -939,7 +941,7 @@ const char * const * StringListStringArray( stringList_t stl )
 			}
 		}
 	}
-	return ( const char * const * )q ;
+	return q ;
 }
 
 void StringListStringArray_1( char * const ** buffer,size_t * size ,stringList_t stl )
