@@ -21,6 +21,9 @@
 #define CRYPTOINFO_H
 
 #include <QWidget>
+#include <QString>
+
+#include <functional>
 
 #include "utility.h"
 
@@ -34,17 +37,21 @@ class cryptoinfo : public QWidget
 {
 	Q_OBJECT
 public:
-	explicit cryptoinfo( QWidget * parent = 0 ) ;
+	cryptoinfo( QWidget * parent,QString path,QString msg ) ;
+	void Show( void ) ;
 	~cryptoinfo() ;
 signals:
 	void closeUISignal( void ) ;
 private slots:
 	void pbOK( void ) ;
+	void checkBoxChecked( bool ) ;
 private:
 	void closeEvent( QCloseEvent * ) ;
 	bool eventFilter( QObject * watched,QEvent * event ) ;
 	void HideUI( void ) ;
 	Ui::cryptoinfo * m_ui ;
+	QString m_path ;
+	QString m_msg ;
 };
 
 #endif // CRYPTOINFO_H
