@@ -17,31 +17,19 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QIcon>
 #include <QApplication>
 #include "zulucrypt.h"
 #include "utility.h"
-#include <QCoreApplication>
-#include <QStringList>
 
 int main( int argc,char * argv[] )
 {
 	QApplication a( argc,argv ) ;
 
-	QCoreApplication::setApplicationName( QString( "zuluCrypt" ) ) ;
+	return utility::startApplication( "zuluCrypt",[ & ](){
+
+		zuluCrypt e ;
+		e.start() ;
 
-	QStringList q = QCoreApplication::arguments() ;
-	if( q.contains( QString( "-h" ) ) ||
-	    q.contains( QString( "-help" ) ) ||
-	    q.contains( QString( "--help" ) ) ||
-	    q.contains( QString( "-v" ) ) ||
-	    q.contains( QString( "-version" ) ) ||
-	    q.contains( QString( "--version" ) ) ){
-		utility::help( QString( "zuluCrypt" ) ) ;
-		return 0 ;
-	}else{
-		zuluCrypt zc ;
-		zc.start() ;
 		return a.exec() ;
-	}
+	} ) ;
 }
