@@ -52,9 +52,9 @@
 
 #include "utility.h"
 
-#define KWALLET         "kde wallet"
-#define INTERNAL_WALLET "internal wallet"
-#define GNOME_WALLET    "gnome wallet"
+#define KWALLET         "KDE Wallet"
+#define INTERNAL_WALLET "Internal Wallet"
+#define GNOME_WALLET    "GNOME keyring"
 
 /*
  * this header is created at config time
@@ -100,18 +100,13 @@ passwordDialog::passwordDialog( QTableWidget * table,QWidget * parent ) : QDialo
 	connect( m_ui->pbKeyOption,SIGNAL( clicked() ),this,SLOT( pbKeyOption() ) ) ;
 	connect( m_ui->cbKeyType,SIGNAL( currentIndexChanged( int ) ),this,SLOT( cbActicated( int ) ) ) ;
 
-	connect( &m_timer,SIGNAL( timeout() ),this,SLOT( setVeraCryptWarning() ) ) ;
-
 	m_ui->PushButtonMountPointPath->setVisible( false ) ;
 	m_ui->pushButtonPassPhraseFromFile->setVisible( false ) ;
 	m_ui->pushButtonPlugin->setVisible( false ) ;
 
-	m_ui->veraCryptWarning->setVisible( false ) ;
-	this->installEventFilter( this ) ;
+	m_veraCryptWarning.setWarningLabel( m_ui->veraCryptWarning ) ;
 
-#if TRUECRYPT_CRYPTSETUP
-	m_ui->cbKeyType->addItem( tr( "TrueCrypt keys" ) ) ;
-#endif
+	this->installEventFilter( this ) ;
 }
 
 bool passwordDialog::eventFilter( QObject * watched,QEvent * event )
@@ -126,56 +121,12 @@ bool passwordDialog::eventFilter( QObject * watched,QEvent * event )
 
 void passwordDialog::pbPlugin()
 {
-	QStringList list ;
-
-	// ZULUCRYPTpluginPath is set at config time and it equals $prefix/lib(64)/zuluCrypt
-
-	QDir dir( QString( ZULUCRYPTpluginPath ) ) ;
-
-	if( dir.exists() ){
-		list = dir.entryList() ;
-
-		list.removeOne( "zuluCrypt-testKey" ) ;
-		list.removeOne( "." ) ;
-		list.removeOne( ".." ) ;
-		list.removeOne( "keyring" ) ;
-		list.removeOne( "kwallet" ) ;
-
-		list.insert( 0,tr( INTERNAL_WALLET ) ) ;
-
-		if( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::kwalletBackEnd ) ){
-			list.insert( 1,tr( KWALLET ) ) ;
-		}
-		if( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::secretServiceBackEnd ) ){
-			list.insert( 2,tr( GNOME_WALLET ) ) ;
-		}
-	}else{
-		list.append( tr( INTERNAL_WALLET ) ) ;
-
-		if( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::kwalletBackEnd ) ){
-			list.append( tr( KWALLET ) ) ;
-		}
-		if( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::secretServiceBackEnd ) ){
-			list.append( tr( GNOME_WALLET ) ) ;
-		}
-	}
-
-	m_pluginMenu->clear() ;
-
-	int j = list.size()  ;
-
-	if( j == 0 ){
-		DialogMsg msg( this ) ;
-		return	msg.ShowUIOK( tr( "ERROR" ),tr( "could not find any plugin installed" ) ) ;
-	}
-
-	for( int i = 0 ; i < j ; i++ ){
-		m_pluginMenu->addAction( list.at( i ) ) ;
-	}
+	utility::createPlugInMenu( m_pluginMenu,tr( INTERNAL_WALLET ),
+				   tr( GNOME_WALLET ),tr( KWALLET ),true ) ;
 
 	m_pluginMenu->addSeparator() ;
 
-	m_pluginMenu->addAction( tr( "cancel" ) ) ;
+	m_pluginMenu->addAction( tr( "Cancel" ) ) ;
 
 	connect( m_pluginMenu,SIGNAL( triggered( QAction * ) ),this,SLOT( pbPluginEntryClicked( QAction * ) ) ) ;
 
@@ -185,7 +136,7 @@ void passwordDialog::pbPlugin()
 void passwordDialog::pbPluginEntryClicked( QAction * e )
 {
 	QString text = e->text() ;
-	if( text != tr( "cancel" ) ){
+	if( text != tr( "Cancel" ) ){
 		m_ui->PassPhraseField->setText( text ) ;
 	}
 }
@@ -202,7 +153,7 @@ void passwordDialog::tcryptCancelled( void )
 void passwordDialog::tcryptGui()
 {
 	this->disableAll() ;
-	m_ui->PassPhraseField->setText( "" ) ;
+	m_ui->PassPhraseField->setText( QString() ) ;
 
 	tcrypt * t = new tcrypt( this ) ;
 	connect( t,SIGNAL( Keys( QString,QStringList ) ),this,SLOT( keys( QString,QStringList ) ) ) ;
@@ -238,8 +189,21 @@ void passwordDialog::closeEvent( QCloseEvent * e )
 	this->HideUI() ;
 }
 
+void passwordDialog::addTcryptVcryptKeyOption()
+{
+	if( m_veraCryptVolume ){
+		m_ui->cbKeyType->addItem( tr( "VeraCrypt Keys" ) ) ;
+	}else{
+		#if TRUECRYPT_CRYPTSETUP
+			m_ui->cbKeyType->addItem( tr( "TrueCrypt Keys" ) ) ;
+		#endif
+	}
+}
+
 void passwordDialog::ShowUI( const QString& volumePath,const QString& mount_point )
 {
+	this->addTcryptVcryptKeyOption() ;
+
 	if( mount_point.isEmpty() ){
 		m_point = utility::mountPathPostFix( volumePath.split( "/" ).last() ) ;
 	}else {
@@ -262,14 +226,32 @@ void passwordDialog::ShowUI( const QString& volumePath,const QString& mount_poin
 	this->show() ;
 }
 
+void passwordDialog::setTitle()
+{
+	if( m_veraCryptVolume ){
+
+		this->setWindowTitle( tr( "Unlock VeraCrypt Volume" ) ) ;
+	}else{
+		this->setWindowTitle( tr( "Unlock Encrypted Volume" ) ) ;
+	}
+}
+
 void passwordDialog::ShowUI( QString dev )
 {
-	QString m_point = QDir::homePath() + "/" + dev.split( "/" ).last() ;
+	this->addTcryptVcryptKeyOption() ;
+
+	this->setTitle() ;
+
+	QString m_point = utility::homePath() + "/" + dev.split( "/" ).last() ;
 	this->ShowUI( dev,m_point ) ;
 }
 
 void passwordDialog::ShowUI()
 {
+	this->addTcryptVcryptKeyOption() ;
+
+	this->setTitle() ;
+
 	this->passphraseOption() ;
 	m_ui->OpenVolumePath->setFocus() ;
 	m_ui->PushButtonVolumePath->setIcon( QIcon( ":/file.png" ) ) ;
@@ -314,15 +296,15 @@ void passwordDialog::pbKeyOption()
 
 void passwordDialog::pluginOption()
 {
-	m_ui->pushButtonPassPhraseFromFile->setToolTip( tr( "choose a module from the file system" ) ) ;
-	m_ui->PassPhraseField->setToolTip( tr( "enter a module name to use to get passphrase" ) ) ;
+	m_ui->pushButtonPassPhraseFromFile->setToolTip( tr( "Choose A Module From The File System" ) ) ;
+	m_ui->PassPhraseField->setToolTip( tr( "Enter A Module Name To Use To Get Passphrase" ) ) ;
 	m_ui->PassPhraseField->setEchoMode( QLineEdit::Normal ) ;
 	m_ui->pushButtonPassPhraseFromFile->setEnabled( false ) ;
-	m_ui->labelPassphrase->setText( tr( "plugin name" ) ) ;
+	m_ui->labelPassphrase->setText( tr( "Plugin Name" ) ) ;
 	m_ui->pushButtonPassPhraseFromFile->setIcon( QIcon( ":/keyfile.png" ) ) ;
 	m_ui->pbKeyOption->setIcon( QIcon( ":/module.png" ) ) ;
 	m_ui->pushButtonPlugin->setEnabled( true ) ;
-	m_ui->pushButtonPlugin->setToolTip( tr( "select a key module" ) ) ;
+	m_ui->pushButtonPlugin->setToolTip( tr( "Select A Key Module" ) ) ;
 	m_ui->pbKeyOption->setEnabled( true ) ;
 	m_ui->PassPhraseField->setEnabled( false ) ;
 	m_ui->PassPhraseField->setText( INTERNAL_WALLET ) ;
@@ -330,11 +312,11 @@ void passwordDialog::pluginOption()
 
 void passwordDialog::passphraseOption()
 {
-	m_ui->PassPhraseField->setToolTip( tr( "enter a key" ) ) ;
+	m_ui->PassPhraseField->setToolTip( tr( "Enter A Key" ) ) ;
 	m_ui->PassPhraseField->setEchoMode( QLineEdit::Password ) ;
 	m_ui->PassPhraseField->clear() ;
 	m_ui->pushButtonPassPhraseFromFile->setEnabled( false ) ;
-	m_ui->labelPassphrase->setText( tr( "key" ) ) ;
+	m_ui->labelPassphrase->setText( tr( "Key" ) ) ;
 	m_ui->pushButtonPassPhraseFromFile->setIcon( QIcon( ":/passphrase.png" ) ) ;
 	m_ui->pushButtonPlugin->setEnabled( false ) ;
 	m_ui->pbKeyOption->setIcon( QIcon( QString() ) ) ;
@@ -344,12 +326,12 @@ void passwordDialog::passphraseOption()
 
 void passwordDialog::passphraseFromFileOption()
 {
-	m_ui->pushButtonPassPhraseFromFile->setToolTip( tr( "choose a key file from the file system" ) ) ;
-	m_ui->PassPhraseField->setToolTip( tr( "enter a path to a keyfile location" ) ) ;
+	m_ui->pushButtonPassPhraseFromFile->setToolTip( tr( "Choose A Key File From The File System" ) ) ;
+	m_ui->PassPhraseField->setToolTip( tr( "Enter A path To A Keyfile Location" ) ) ;
 	m_ui->PassPhraseField->setEchoMode( QLineEdit::Normal ) ;
 	m_ui->PassPhraseField->clear() ;
 	m_ui->pushButtonPassPhraseFromFile->setEnabled( true ) ;
-	m_ui->labelPassphrase->setText( tr( "keyfile path" ) ) ;
+	m_ui->labelPassphrase->setText( tr( "Keyfile Path" ) ) ;
 	m_ui->pushButtonPassPhraseFromFile->setIcon( QIcon( ":/keyfile.png" ) ) ;
 	m_ui->pushButtonPlugin->setEnabled( false ) ;
 	m_ui->pbKeyOption->setIcon( QIcon( ":/keyfile.png" ) ) ;
@@ -362,12 +344,12 @@ void passwordDialog::clickedPassPhraseFromFileButton()
 {
 	QString msg ;
 	if( m_ui->cbKeyType->currentIndex() == passwordDialog::keyfile ){
-		msg = tr( "Select a keyfile" ) ;
+		msg = tr( "Select A Keyfile" ) ;
 	}else{
-		msg = tr( "Select a key module" ) ;
+		msg = tr( "Select A Key Module" ) ;
 	}
 
-	QString Z = QFileDialog::getOpenFileName( this,msg,QDir::homePath(),0 ) ;
+	QString Z = QFileDialog::getOpenFileName( this,msg,utility::homePath(),0 ) ;
 	if( !Z.isEmpty() ){
 		m_ui->PassPhraseField->setText( Z ) ;
 	}
@@ -375,8 +357,8 @@ void passwordDialog::clickedPassPhraseFromFileButton()
 
 void passwordDialog::mount_point( void )
 {
-	QString p = tr( "Select Path to mount point folder" ) ;
-	QString Z = QFileDialog::getExistingDirectory( this,p,QDir::homePath(),QFileDialog::ShowDirsOnly ) ;
+	QString p = tr( "Select Path To Mount Point Folder" ) ;
+	QString Z = QFileDialog::getExistingDirectory( this,p,utility::homePath(),QFileDialog::ShowDirsOnly ) ;
 
 	if( !Z.isEmpty() ){
 		Z = Z + "/" + m_ui->OpenVolumePath->text().split( "/" ).last() ;
@@ -392,7 +374,8 @@ void passwordDialog::mount_point( void )
 
 void passwordDialog::file_path( void )
 {
-	QString Z = QFileDialog::getOpenFileName( this,tr( "Select encrypted volume" ),QDir::homePath(),0 ) ;
+
+	QString Z = QFileDialog::getOpenFileName( this,tr( "Select Encrypted volume" ),utility::homePath(),0 ) ;
 	m_ui->OpenVolumePath->setText( Z ) ;
 	if( !Z.isEmpty() ){
 		m_ui->MountPointPath->setText( utility::mountPathPostFix( Z.split( "/" ).last() ) ) ;
@@ -429,7 +412,7 @@ void passwordDialog::buttonOpenClicked( void )
 			if( w.notConfigured ){
 
 				DialogMsg msg( this ) ;
-				msg.ShowUIOK( tr( "ERROR!" ),tr( "internal wallet is not configured" ) ) ;
+				msg.ShowUIOK( tr( "ERROR!" ),tr( "Internal wallet is not configured" ) ) ;
 				return this->enableAll() ;
 
 			}else{
@@ -448,7 +431,7 @@ void passwordDialog::buttonOpenClicked( void )
 
 			if( w.key.isEmpty() ){
 				DialogMsg msg( this ) ;
-				msg.ShowUIOK( tr( "ERROR" ),tr( "the volume does not appear to have an entry in the wallet" ) ) ;
+				msg.ShowUIOK( tr( "ERROR!" ),tr( "The volume does not appear to have an entry in the wallet" ) ) ;
 				this->enableAll() ;
 			}else{
 				m_key = w.key ;
@@ -531,13 +514,13 @@ void passwordDialog::openVolume()
 	m_point = m_ui->MountPointPath->text() ;
 	if( m_point.isEmpty() || m_device.isEmpty() ){
 		DialogMsg msg( this ) ;
-		msg.ShowUIOK( tr( "ERROR!" ),tr( "atleast one required field is empty" ) ) ;
+		msg.ShowUIOK( tr( "ERROR!" ),tr( "Atleast one required field is empty" ) ) ;
 		return this->enableAll() ;
 	}
 
-	if( m_point.contains( QString( "/" ) ) ){
+	if( m_point.contains( "/" ) ){
 		DialogMsg msg( this ) ;
-		msg.ShowUIOK( tr( "ERROR" ),tr( "\"/\" character is not allowed in mount name field" ) ) ;
+		msg.ShowUIOK( tr( "ERROR!" ),tr( "\"/\" character is not allowed in mount name field" ) ) ;
 		m_ui->OpenVolumePath->setFocus() ;
 		return this->enableAll() ;
 	}
@@ -559,7 +542,7 @@ void passwordDialog::openVolume()
 	if( keySource == passwordDialog::keyfile ){
 		if( m_key.isEmpty() ){
 			DialogMsg msg( this ) ;
-			msg.ShowUIOK( tr( "ERROR!" ),tr( "atleast one required field is empty" ) ) ;
+			msg.ShowUIOK( tr( "ERROR!" ),tr( "Atleast one required field is empty" ) ) ;
 			return this->enableAll() ;
 		}else{
 			passtype = "-f" ;
@@ -572,7 +555,7 @@ void passwordDialog::openVolume()
 	}else if( keySource == passwordDialog::plugin ){
 		if( m_key.isEmpty() ){
 			DialogMsg msg( this ) ;
-			msg.ShowUIOK( tr( "ERROR!" ),tr( "atleast one required field is empty" ) ) ;
+			msg.ShowUIOK( tr( "ERROR!" ),tr( "Atleast one required field is empty" ) ) ;
 			return this->enableAll() ;
 		}else{
 			QString r = m_ui->PassPhraseField->text() ;
@@ -593,7 +576,7 @@ void passwordDialog::openVolume()
 		qDebug() << "Error: uncaught condition" ;
 	}
 
-	QString a = QString( ZULUCRYPTzuluCrypt ) ;
+	QString a = ZULUCRYPTzuluCrypt ;
 	QString b = m_device ;
 	b.replace( "\"","\"\"\"" ) ;
 	QString c = m_point ;
@@ -611,58 +594,37 @@ void passwordDialog::openVolume()
 			QString e = it ;
 			e.replace( "\"","\"\"\"" ) ;
 
-			exe += " -F " + e ;
+			exe += " -F \"" + e + "\"" ;
 		}
 	}
 
 	if( m_veraCryptVolume ){
 
-		m_time = 0 ;
-		m_timer.stop() ;
-
-		m_ui->veraCryptWarning->setVisible( true ) ;
-
-		this->setVeraCryptWarning() ;
-
-		m_timer.start( 1000 * 1 ) ;
-
 		exe += " -t vera" ;
 	}
 
 	this->disableAll() ;
 
+	m_veraCryptWarning.show( m_veraCryptVolume ) ;
+
 	m_working = true ;
 
-	auto r = utility::Task::run( exe ).await() ;
+	auto r = utility::Task::run( utility::appendUserUID( exe ) ).await() ;
 
 	m_working = false ;
 
+	m_veraCryptWarning.stopTimer() ;
+
 	if( r.success() ){
 
 		this->success( r.output() ) ;
 	}else{
 		this->failed( r.exitCode() ) ;
 
-		m_ui->veraCryptWarning->setVisible( false ) ;
+		m_veraCryptWarning.hide() ;
 	}
 }
 
-void passwordDialog::setVeraCryptWarning()
-{
-	QString e = tr( "please be patient as unlocking a VeraCrypt volume may take a very long time.\n\n" ) ;
-
-	if( m_time >= 60 ){
-
-		e += tr( "Elapsed time: %0 minutes" ).arg( QString::number( m_time / 60,'f',2 ) ) ;
-	}else{
-		e += tr( "Elapsed time: %0 seconds" ).arg( QString::number( m_time ) ) ;
-	}
-
-	m_time++ ;
-
-	m_ui->veraCryptWarning->setText( e ) ;
-}
-
 void passwordDialog::success( const QByteArray& r )
 {
 	if( utility::mapperPathExists( m_device ) ){
@@ -681,6 +643,8 @@ void passwordDialog::success( const QByteArray& r )
 			list.append( "plain" ) ;
 		}else if( r.contains( "tcrypt" ) ){
 			list.append( "tcrypt" ) ;
+		}else if( r.contains( "vcrypt" ) ){
+			list.append( "vcrypt" ) ;
 		}else{
 			list.append( "Nil" ) ;
 		}
@@ -713,31 +677,31 @@ void passwordDialog::failed( int r )
 	DialogMsg msg( this ) ;
 	switch ( r ){
 		case 0 : ;
-		case 1 : msg.ShowUIOK( tr( "ERROR!" ),tr( "failed to mount ntfs/exfat file system using ntfs-3g,is ntfs-3g/exfat package installed?" ) ) ; break ;
-		case 2 : msg.ShowUIOK( tr( "ERROR!" ),tr( "there seem to be an open volume accociated with given address" ) ) ;				break ;
-		case 3 : msg.ShowUIOK( tr( "ERROR!" ),tr( "no file or device exist on given path" ) ) ; 						break ;
-		case 4 : msg.ShowUIOK( tr( "ERROR!" ),tr( "volume could not be opened with the presented key" ) ) ;					break ;
-		case 5 : msg.ShowUIOK( tr( "ERROR!" ),tr( "insufficient privilege to mount the device with given options" ) ) ;				break ;
-		case 6 : msg.ShowUIOK( tr( "ERROR!" ),tr( "insufficient privilege to open device in read write mode or device does not exist" ) ) ;	break ;
-		case 7 : msg.ShowUIOK( tr( "ERROR!" ),tr( "only root user can perform this operation" ) ) ;						break ;
+		case 1 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Failed to mount ntfs/exfat file system using ntfs-3g,is ntfs-3g/exfat package installed?" ) ) ; break ;
+		case 2 : msg.ShowUIOK( tr( "ERROR!" ),tr( "There seem to be an open volume accociated with given address" ) ) ;				break ;
+		case 3 : msg.ShowUIOK( tr( "ERROR!" ),tr( "No file or device exist on given path" ) ) ; 						break ;
+		case 4 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Volume could not be opened with the presented key" ) ) ;					break ;
+		case 5 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient privilege to mount the device with given options" ) ) ;				break ;
+		case 6 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient privilege to open device in read write mode or device does not exist" ) ) ;	break ;
+		case 7 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Only root user can perform this operation" ) ) ;						break ;
 		case 8 : msg.ShowUIOK( tr( "ERROR!" ),tr( "-O and -m options can not be used together" ) ) ;						break ;
-		case 9 : msg.ShowUIOK( tr( "ERROR!" ),tr( "could not create mount point, invalid path or path already taken" ) ) ;			break ;
-		case 10: msg.ShowUIOK( tr( "ERROR!" ),tr( "shared mount point path aleady taken" ) ) ;							break ;
-		case 11: msg.ShowUIOK( tr( "ERROR!" ),tr( "there seem to be an opened mapper associated with the device" ) ) ;				break ;
-		case 12: msg.ShowUIOK( tr( "ERROR!" ),tr( "could not get a passphrase from the module" ) ) ;						break ;
-		case 13: msg.ShowUIOK( tr( "ERROR!" ),tr( "could not get passphrase in silent mode" ) ) ;						break ;
-		case 14: msg.ShowUIOK( tr( "ERROR!" ),tr( "insufficient memory to hold passphrase" ) ) ;							break ;
-		case 15: msg.ShowUIOK( tr( "ERROR!" ),tr( "one or more required argument(s) for this operation is missing" ) ) ;				break ;
-		case 16: msg.ShowUIOK( tr( "ERROR!" ),tr( "invalid path to key file" ) ) ;								break ;
-		case 17: msg.ShowUIOK( tr( "ERROR!" ),tr( "could not get enought memory to hold the key file" ) ) ;					break ;
-		case 18: msg.ShowUIOK( tr( "ERROR!" ),tr( "insufficient privilege to open key file for reading" ) ) ;					break ;
-		case 19: msg.ShowUIOK( tr( "ERROR!" ),tr( "could not get a passphrase through a local socket" ) ) ;					break ;
-		case 20: msg.ShowUIOK( tr( "ERROR!" ),tr( "failed to mount a filesystem:invalid/unsupported mount option or unsupported file system encountered" ) ) ;	break ;
-		case 21: msg.ShowUIOK( tr( "ERROR!" ),tr( "could not create a lock on /etc/mtab" ) ) ;							break ;
-		case 22: msg.ShowUIOK( tr( "ERROR!" ),tr( "insufficient privilege to open a system volume.\n\nConsult menu->help->permission for more informaion\n" ) ) ;					break ;
-		case 113:msg.ShowUIOK( tr( "ERROR!" ),tr( "a non supported device encountered,device is missing or permission denied\n\
+		case 9 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not create mount point, invalid path or path already taken" ) ) ;			break ;
+		case 10: msg.ShowUIOK( tr( "ERROR!" ),tr( "Shared mount point path aleady taken" ) ) ;							break ;
+		case 11: msg.ShowUIOK( tr( "ERROR!" ),tr( "There seem to be an opened mapper associated with the device" ) ) ;				break ;
+		case 12: msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not get a passphrase from the module" ) ) ;						break ;
+		case 13: msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not get passphrase in silent mode" ) ) ;						break ;
+		case 14: msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient memory to hold passphrase" ) ) ;							break ;
+		case 15: msg.ShowUIOK( tr( "ERROR!" ),tr( "One or more required argument(s) for this operation is missing" ) ) ;				break ;
+		case 16: msg.ShowUIOK( tr( "ERROR!" ),tr( "Invalid path to key file" ) ) ;								break ;
+		case 17: msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not get enought memory to hold the key file" ) ) ;					break ;
+		case 18: msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient privilege to open key file for reading" ) ) ;					break ;
+		case 19: msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not get a passphrase through a local socket" ) ) ;					break ;
+		case 20: msg.ShowUIOK( tr( "ERROR!" ),tr( "Failed to mount a filesystem:invalid/unsupported mount option or unsupported file system encountered" ) ) ;	break ;
+		case 21: msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not create a lock on /etc/mtab" ) ) ;							break ;
+		case 22: msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient privilege to open a system volume.\n\nConsult menu->help->permission for more informaion\n" ) ) ;					break ;
+		case 113:msg.ShowUIOK( tr( "ERROR!" ),tr( "A non supported device encountered,device is missing or permission denied\n\
 Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The device has LVM or MDRAID signature" ) ) ;					break ;
-		default: msg.ShowUIOK( tr( "ERROR!" ),tr( "unrecognized ERROR with status number %1 encountered" ).arg( r ) ) ;
+		default: msg.ShowUIOK( tr( "ERROR!" ),tr( "Unrecognized ERROR with status number %1 encountered" ).arg( r ) ) ;
 	}
 
 	this->enableAll() ;
