@@ -30,7 +30,7 @@
 #include <pwd.h>
 
 #include <QDebug>
-
+#include <QCoreApplication>
 #include <blkid/blkid.h>
 #include <QByteArray>
 #include <QProcess>
@@ -55,6 +55,7 @@
 #include "storage_manager.h"
 #include "dialogmsg.h"
 #include "support_whirlpool.h"
+#include "readonlywarning.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -68,6 +69,100 @@
 
 #include "../zuluCrypt-cli/pluginManager/libzuluCryptPluginManager.h"
 
+#include "../zuluCrypt-cli/utility/process/process.h"
+
+#include "plugin_path.h"
+
+static int staticGlobalUserId = -1 ;
+
+void utility::setUID( int uid )
+{
+	staticGlobalUserId = uid ;
+}
+
+int utility::getUID()
+{
+	return staticGlobalUserId ;
+}
+
+int utility::getUserID()
+{
+	if( staticGlobalUserId == -1 ){
+
+		return getuid() ;
+	}else{
+		return staticGlobalUserId ;
+	}
+}
+
+QString utility::getStringUserID()
+{
+	return QString::number( utility::getUserID() ) ;
+}
+
+QString utility::appendUserUID( const QString& e )
+{
+	if( staticGlobalUserId == -1 ){
+
+		return e ;
+	}else{
+		return e + " -K " + utility::getStringUserID() ;
+	}
+}
+
+static passwd * _getPassWd()
+{
+	return getpwuid( utility::getUserID() ) ;
+}
+
+QString utility::userName()
+{
+	return _getPassWd()->pw_name ;
+}
+
+QString utility::homePath()
+{
+	return getpwuid( utility::getUserID() )->pw_dir ;
+}
+
+static int _help()
+{
+	std::cout << "\n" << VERSION_STRING << std::endl ;
+
+	QString helpMsg = QObject::tr( "\n\
+options:\n\
+	-d   path to where a volume to be auto unlocked/mounted is located\n\
+	-m   tool to use to open a default file manager(default tool is xdg-open)\n\
+	-e   start the application without showing the GUI\n" ) ;
+
+	std::cout << helpMsg.toLatin1().constData() << std::endl ;
+
+	return 0 ;
+}
+
+static bool _printHelpOrVersionInfo()
+{
+	QStringList q = QCoreApplication::arguments() ;
+	return q.contains( "-h" )        ||
+	       q.contains( "-help" )     ||
+	       q.contains( "--help" )    ||
+	       q.contains( "-v" )        ||
+	       q.contains(  "-version" ) ||
+	       q.contains( "--version" ) ;
+}
+
+int utility::startApplication( const char * appName,std::function<int()> start )
+{
+	QCoreApplication::setApplicationName( appName ) ;
+
+	if( _printHelpOrVersionInfo() ){
+
+		return _help() ;
+	}else{
+		return start() ;
+	}
+}
+
 void utility::keySend( const QString& path,const QString& key )
 {
 	::Task::exec( [ path,key ](){
@@ -90,6 +185,50 @@ void utility::keySend( const QString& path,const QString& key )
 	} ) ;
 }
 
+void utility::createPlugInMenu( QMenu * menu,const QString& a,const QString& b,const QString& c,bool addPlugIns )
+{
+	QStringList l ;
+	QStringList e ;
+
+	l.append( a ) ;
+
+	if( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::secretServiceBackEnd ) ){
+		l.append( b ) ;
+	}
+	if( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::kwalletBackEnd ) ){
+		l.append( c ) ;
+	}
+
+	if( addPlugIns ){
+
+		QDir dir( ZULUCRYPTpluginPath ) ;
+
+		if( dir.exists() ){
+
+			e = dir.entryList() ;
+
+			e.removeOne( "zuluCrypt-testKey" ) ;
+			e.removeOne( "." ) ;
+			e.removeOne( ".." ) ;
+			e.removeOne( "keyring" ) ;
+			e.removeOne( "kwallet" ) ;
+		}
+	}
+
+	menu->clear() ;
+
+	auto _add_actions = [ menu ]( const QStringList& r ){
+
+		for( const auto& it : r ){
+
+			menu->addAction( it ) ;
+		}
+	} ;
+
+	_add_actions( l ) ;
+	_add_actions( e ) ;
+}
+
 ::Task::future<int>& utility::exec( const QString& exe )
 {
 	return ::Task::run<int>( [ exe ](){ return utility::Task( exe ).exitCode() ; } ) ;
@@ -99,7 +238,9 @@ void utility::keySend( const QString& path,const QString& key )
 {
 	return ::Task::run<QStringList>( [ volumePath ](){
 
-		auto r = utility::Task( QString( "%1 -b -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,volumePath ) ) ;
+		QString e = utility::appendUserUID( "%1 -b -d \"%2\"" ) ;
+
+		auto r = utility::Task( e.arg( ZULUCRYPTzuluCrypt,volumePath ) ) ;
 
 		QStringList l ;
 
@@ -150,7 +291,7 @@ void utility::keySend( const QString& path,const QString& key )
 
 		QString device = dev ;
 		device = device.replace( "\"", "\"\"\"" ) ;
-		QString exe = QString( "%1 -U -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt ).arg( device ) ;
+		QString exe = utility::appendUserUID( "%1 -U -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,device ) ;
 
 		auto r = utility::Task( exe ) ;
 
@@ -170,14 +311,16 @@ void utility::keySend( const QString& path,const QString& key )
 	} ) ;
 }
 
-::Task::future<bool>& utility::openMountPoint( const QString& path,const QString& opener )
+::Task::future<bool>& utility::openMountPoint( const QString& path,const QString& opener,const QString& env )
 {
+	Q_UNUSED( env ) ;
+
 	return ::Task::run<bool>( [ path,opener ](){
 
 		QString e = path ;
 		e.replace( "\"","\"\"\"" ) ;
 
-		auto r = utility::Task( QString( "%1 \"%2\"" ).arg( opener ).arg( e ) ) ;
+		auto r = utility::Task( QString( "%1 \"%2\"" ).arg( opener,e ) ) ;
 
 		return r.exitCode() != 0 || r.exitStatus() != 0 ;
 	} ) ;
@@ -278,7 +421,7 @@ static std::function< void( int ) > _closeFunction( const QString& e )
 
 				if( close( fd ) == 0 ){
 
-					utility::Task( QString( "%1 -q -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,e ) ) ;
+					utility::Task( utility::appendUserUID( "%1 -q -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,e ) ) ;
 
 					break ;
 				}
@@ -300,7 +443,7 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 
 		volumePath.replace( "\"","\"\"\"" ) ;
 
-		int r = utility::Task( QString( "%1 -k -J -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,volumePath ) ).exitCode() ;
+		int r = utility::Task( utility::appendUserUID( "%1 -k -J -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,volumePath ) ).exitCode() ;
 
 		if( r != 0 ){
 			return r ;
@@ -338,7 +481,9 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 						i = int( ( size_written * 100 / size ) ) ;
 
 						if( i > j ){
+
 							function( i ) ;
+
 							j = i ;
 						}
 					}
@@ -353,7 +498,7 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 QString utility::cryptMapperPath()
 {
 	//return QString( crypt_get_dir() )
-	return QString( "/dev/mapper/" ) ;
+	return "/dev/mapper/" ;
 }
 
 bool utility::userIsRoot()
@@ -361,28 +506,6 @@ bool utility::userIsRoot()
 	return getuid() == 0 ;
 }
 
-QString utility::userName()
-{
-	return QString( getpwuid( getuid() )->pw_name ) ;
-}
-
-void utility::help( const QString& app )
-{
-	Q_UNUSED( app ) ;
-
-	std::cout << VERSION_STRING << std::endl ;
-
-	QString helpMsg = QObject::tr( "\n\
-options:\n\
-	-d   path to where a volume to be auto unlocked/mounted is located\n\
-	-m   tool to use to open a default file manager(default tool is xdg-open)\n\
-	-e   start the application without showing the GUI\n" ) ;
-
-	QByteArray s = helpMsg.toLatin1() ;
-
-	std::cout << s.constData() << std::endl ;
-}
-
 QString utility::shareMountPointToolTip()
 {
 	QString s = QObject::tr( "\
@@ -398,26 +521,26 @@ QString utility::shareMountPointToolTip( const QString& path )
 	QByteArray x = s.toLatin1() ;
 	const char * y = x.constData() ;
 	if( stat( y,&st ) == 0 ){
-		return QString( "public mount point: " ) + s ;
+		return "public mount point: " + s ;
 	}else{
 		//return QString( "no public mount point" ) ;
-		return QString( "" ) ;
+		return QString() ;
 	}
 }
 
 QString utility::sharedMountPointPath( const QString& path )
 {
-	if( path == QString( "/" ) ){
-		return QString( "" ) ;
+	if( path == "/" ){
+		return QString() ;
 	}else{
 		struct stat st ;
-		QString s = QString( "/run/media/public/" ) + path.split( "/" ).last() ;
+		QString s = "/run/media/public/" + path.split( "/" ).last() ;
 		QByteArray x = s.toLatin1() ;
 		const char * y = x.constData() ;
 		if( stat( y,&st ) == 0 ){
 			return s ;
 		}else{
-			return QString( "" ) ;
+			return QString() ;
 		}
 	}
 }
@@ -533,101 +656,39 @@ bool utility::pathIsReadable( const QString& path )
 	}
 }
 
-bool utility::setOpenVolumeReadOnly( QWidget * parent,bool check,const QString& app )
+bool utility::setOpenVolumeReadOnly( QWidget * parent,bool checked,const QString& app )
 {
-	QString Path = QDir::homePath() + "/.zuluCrypt/" + app ;
-	QFile f( Path + "-openMode" ) ;
-
-	f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-	if( check ){
-		f.write( "1" ) ;
-	}else{
-		f.write( "0" ) ;
-	}
-
-	f.close() ;
-
-	DialogMsg msg( parent ) ;
-	QString m = QObject::tr( "setting this option will cause the volume to open in read only mode" ) ;
-
-	QString path = Path + "-readOnlyOption" ;
-
-	f.setFileName( path ) ;
-
-	bool st ;
-	if( f.exists() ){
-		f.open( QIODevice::ReadWrite ) ;
-		QByteArray opt = f.readAll() ;
-		if( opt == QByteArray( "0" ) && check ) {
-			f.seek( 0 ) ;
-
-			st = msg.ShowUIOKDoNotShowOption( QObject::tr( "info" ),m ) ;
-
-			if( st ){
-				f.write( "1" ) ;
-			}else{
-				f.write( "0" ) ;
-			}
-
-			f.close() ;
-		}
-	}else{
-		st = msg.ShowUIOKDoNotShowOption( QObject::tr( "info" ),m ) ;
-
-		f.open( QIODevice::WriteOnly ) ;
-
-		if( st ){
-			f.write( "1" ) ;
-		}else{
-			f.write( "0" ) ;
-		}
-
-		f.close() ;
-	}
-
-	return check ;
+	return readOnlyWarning::showWarning( parent,checked,app ) ;
 }
 
 bool utility::getOpenVolumeReadOnlyOption( const QString& app )
 {
-	QString home = QDir::homePath() + "/.zuluCrypt/" ;
-	QDir d( home ) ;
-
-	if( !d.exists() ){
-		d.mkdir( home ) ;
-	}
-
-	QFile f( home + app + "-openMode" ) ;
-
-	if( !f.exists() ){
-		f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-		f.write( "0" ) ;
-		f.close() ;
-	}
-
-	f.open( QIODevice::ReadOnly ) ;
-	int st = QString( f.readAll() ).toInt() ;
-
-	f.close() ;
-	return st == 1 ;
+	return readOnlyWarning::getOpenVolumeReadOnlyOption( app ) ;
 }
 
 QString utility::keyPath()
 {
 	QFile f( "/dev/urandom" ) ;
+
 	f.open( QIODevice::ReadOnly ) ;
+
 	QByteArray data = f.read( 64 ) ;
-	QString a = QDir::homePath() ;
-	QString b = utility::hashPath( data ).mid( 1 ) ;
-	return QString( "%1/.zuluCrypt-socket/%2" ).arg( a ).arg( b ) ;
+
+	QString a = utility::homePath() ;
+
+	return QString( "%1/.zuluCrypt-socket/%2" ).arg( a,utility::hashPath( data ).mid( 1 ) ) ;
 }
 
 bool utility::eventFilter( QObject * gui,QObject * watched,QEvent * event )
 {
 	if( watched == gui ){
+
 		if( event->type() == QEvent::KeyPress ){
+
 			QKeyEvent * keyEvent = static_cast< QKeyEvent* >( event ) ;
+
 			if( keyEvent->key() == Qt::Key_Escape ){
+
 				return true ;
 			}
 		}
@@ -649,12 +710,16 @@ QStringList utility::split(const QByteArray& str,char token )
 
 bool utility::mapperPathExists( const QString& path )
 {
-	return utility::pathExists( utility::mapperPath( path ) ) ;
+	if( utility::pathExists( utility::mapperPath( path ) ) ){
+		return true ;
+	}else{
+		return utility::pathExists( utility::mapperPath( path,"-VERA-" ) ) ;
+	}
 }
 
 QString utility::mountPath( const QString& path )
 {
-	auto pass = getpwuid( getuid() ) ;
+	auto pass = _getPassWd() ;
 
 #if USE_HOME_PATH_AS_MOUNT_PREFIX
 	return QString( "%1/%2" ).arg( QString( pass->pw_dir ) ).arg( path ) ;
@@ -665,10 +730,10 @@ QString utility::mountPath( const QString& path )
 
 QString utility::homeMountPath( const QString& path )
 {
-	return QString( "%1/%2" ).arg( getpwuid( getuid() )->pw_dir ).arg( path ) ;
+	return QString( "%1/%2" ).arg( _getPassWd()->pw_dir,path ) ;
 }
 
-QString utility::mountPathPostFix( const QString& path,bool encfs )
+QString utility::mountPathPostFix( const QString& path )
 {
 	if( path.isEmpty() ){
 
@@ -676,13 +741,7 @@ QString utility::mountPathPostFix( const QString& path,bool encfs )
 	}else{
 		auto _path_not_found = []( const QString& e ){ return !utility::pathExists( e ) ; } ;
 
-		QString e ;
-
-		if( encfs ){
-			e = utility::homeMountPath( path ) ;
-		}else{
-			e = utility::mountPath( path ) ;
-		}
+		QString e = utility::mountPath( path ) ;
 
 		if( _path_not_found( e ) ){
 
@@ -705,23 +764,30 @@ QString utility::mountPathPostFix( const QString& path,bool encfs )
 	}
 }
 
-QString utility::mapperPath( const QString& r )
+QString utility::mapperPath( const QString& r,const QString& component )
 {
 	QString rpath = r ;
 
-	QString path = utility::cryptMapperPath() + QString( "zuluCrypt-" ) + QString::number( getuid() ) ;
+	QString path = utility::cryptMapperPath() + "zuluCrypt-" + utility::getStringUserID() ;
 
 	if( rpath.startsWith( "UUID=" ) ){
+
 		rpath.remove( QChar( '\"' ) ) ;
 		rpath.replace( "UUID=","UUID-" ) ;
 		path += QString( "-" ) + rpath + utility::hashPath( rpath.toLatin1() ) ;
 	}else{
-		path += "-NAAN-" + rpath.split( "/" ).last() + utility::hashPath( rpath.toLatin1() ) ;
+		if( component.isEmpty() ){
+
+			path += "-NAAN-" + rpath.split( "/" ).last() + utility::hashPath( rpath.toLatin1() ) ;
+		}else{
+			path += component + rpath.split( "/" ).last() + utility::hashPath( rpath.toLatin1() ) ;
+		}
 	}
 
 	QString z = QString( BASH_SPECIAL_CHARS ) ;
 
 	for( const auto& it : z ){
+
 		path.replace( it,QChar( '_' ) ) ;
 	}
 	return path ;
@@ -769,9 +835,9 @@ bool utility::canCreateFile( const QString& path )
 QString utility::resolvePath( const QString& path )
 {
 	if( path.size() == 1 && path.at( 0 ) == QChar( '~' ) ){
-		return QDir::homePath() + "/" ;
+		return utility::homePath() + "/" ;
 	}else if( path.startsWith( "~/" ) ){
-		return QDir::homePath() + "/" + path.mid( 2 ) ;
+		return utility::homePath() + "/" + path.mid( 2 ) ;
 	}else if( path.startsWith( "UUID=") ){
 		return path ;
 	}else if( path.startsWith( "/dev/" ) ){
@@ -807,8 +873,8 @@ QString utility::cmdArgumentValue( const QStringList& l,const QString& arg,const
 
 void utility::addToFavorite( const QString& dev,const QString& m_point )
 {
-	QString fav = QString( "%1\t%2\n" ).arg( dev ).arg( m_point ) ;
-	QFile f( QDir::homePath() + QString( "/.zuluCrypt/favorites" ) ) ;
+	QString fav = QString( "%1\t%2\n" ).arg( dev,m_point ) ;
+	QFile f( utility::homePath() + "/.zuluCrypt/favorites" ) ;
 	f.open( QIODevice::WriteOnly | QIODevice::Append ) ;
 	f.write( fav.toLatin1() ) ;
 	f.close() ;
@@ -816,7 +882,7 @@ void utility::addToFavorite( const QString& dev,const QString& m_point )
 
 QStringList utility::readFavorites()
 {
-	QFile f( QDir::homePath() + "/.zuluCrypt/favorites" ) ;
+	QFile f( utility::homePath() + "/.zuluCrypt/favorites" ) ;
 	QStringList list ;
 	if( f.open( QIODevice::ReadOnly ) ){
 		QString data( f.readAll() ) ;
@@ -830,7 +896,7 @@ QStringList utility::readFavorites()
 
 void utility::removeFavoriteEntry( const QString& entry )
 {
-	QFile f( QDir::homePath() + "/.zuluCrypt/favorites" ) ;
+	QFile f( utility::homePath() + "/.zuluCrypt/favorites" ) ;
 	f.open( QIODevice::ReadOnly ) ;
 	QByteArray b = f.readAll() ;
 	f.close() ;
