@@ -69,6 +69,7 @@
 #include "lxqt_wallet/frontend/lxqt_wallet.h"
 
 #include "veracrypt_support.h"
+#include "pdf_path.h"
 
 zuluCrypt::zuluCrypt( QWidget * parent ) :QMainWindow( parent ),m_trayIcon( 0 )
 {
@@ -79,34 +80,21 @@ zuluCrypt::zuluCrypt( QWidget * parent ) :QMainWindow( parent ),m_trayIcon( 0 )
 void zuluCrypt::setLocalizationLanguage()
 {
 	QTranslator * translator = new QTranslator( this ) ;
-	QString program  = "zuluCrypt-gui" ;
-	QString lang     = utility::localizationLanguage( program ) ;
-	QString langPath = utility::localizationLanguagePath( program ) ;
 
-	QByteArray r = lang.toLatin1() ;
+	const char * app = "zuluCrypt-gui" ;
 
-	QByteArray e( "en_US" ) ;
-	if( e == r ){
+	QByteArray r = utility::localizationLanguage( app ).toLatin1() ;
+
+	if( r == "en_US" ){
 		/*
 		 *english_US language,its the default and hence dont load anything
 		 */
 	}else{
-		translator->load( r.constData(),langPath ) ;
+		translator->load( r.constData(),utility::localizationLanguagePath( app ) ) ;
 		QCoreApplication::installTranslator( translator ) ;
 	}
 }
 
-void zuluCrypt::setFolderOpener()
-{
-	//currently not used
-	QStringList argv = QCoreApplication::arguments() ;
-	if( argv.size() < 2 ){
-		m_folderOpener = "xdg-open" ;
-	}else{
-		m_folderOpener = argv.at( 1 ) ;
-	}
-}
-
 void zuluCrypt::setUpApp( const QString& volume )
 {
 	this->setupUIElements() ;
@@ -115,6 +103,7 @@ void zuluCrypt::setUpApp( const QString& volume )
 	this->initKeyCombo() ;
 	this->initTray() ;
 	this->updateVolumeList( volume ) ;
+	this->info() ;
 }
 
 void zuluCrypt::updateVolumeList( const QString& volume )
@@ -141,17 +130,22 @@ void zuluCrypt::updateVolumeList( const QString& volume )
 			for( const auto& it : l ){
 
 				z = utility::split( it,'\t' ) ;
+
 				if( z.size() >= 3 ){
 
-					const QString& fs = z.at( 2 ) ;
+					const QString& q = z.at( 2 ) ;
+
+					if( q.startsWith( "crypto_LUKS" ) ){
 
-					if( fs.startsWith( "crypto_LUKS" ) ){
 						z.replace( 2,"luks" ) ;
-					}else if( fs == "crypto_PLAIN" ){
-						z.replace( 2,"plain" ) ;
-					}else if( fs == "crypto_TCRYPT" ){
-						z.replace( 2,"tcrypt" ) ;
+					}else{
+						QString e( q ) ;
+
+						e.remove( "crypto_" ) ;
+
+						z.replace( 2,e.toLower() ) ;
 					}
+
 					tablewidget::addRowToTable( m_ui->tableWidget,z ) ;
 				}
 			}
@@ -178,14 +172,6 @@ void zuluCrypt::updateVolumeListAction()
 	}
 }
 
-void zuluCrypt::processArgumentList()
-{
-}
-
-void zuluCrypt::openVolumeFromArgumentList()
-{
-}
-
 void zuluCrypt::initKeyCombo()
 {
 	QAction * rca = new QAction( this ) ;
@@ -209,7 +195,7 @@ void zuluCrypt::raiseWindow()
 		m_trayIcon->setVisible( true ) ;
 	}else{
 		this->setVisible( true ) ;
-		this->show() ; ;
+		this->show() ;
 		this->raise() ;
 		this->setWindowState( Qt::WindowActive ) ;
 	}
@@ -218,7 +204,7 @@ void zuluCrypt::raiseWindow()
 void zuluCrypt::raiseWindow( QString device )
 {
 	this->setVisible( true ) ;
-	this->show() ; ;
+	this->show() ;
 	this->raise() ;
 	this->setWindowState( Qt::WindowActive ) ;
 	QString y = device.split( "/" ).last() ;
@@ -238,15 +224,21 @@ void zuluCrypt::start()
 	QStringList l = QCoreApplication::arguments() ;
 
 	QString e      = utility::cmdArgumentValue( l,"-d" ) ;
-	m_folderOpener = utility::cmdArgumentValue( l,"-m","xdg-open" ) ;
+	m_openPath     = utility::cmdArgumentValue( l,"-m","xdg-open" ) ;
 	m_startHidden  = l.contains( "-e" ) ;
 
-	QString sockpath = QString( "zuluCrypt-gui.socket" ) ;
-	oneinstance * instance = new oneinstance( this,sockpath,"raiseWindow",e ) ;
-	connect( instance,SIGNAL( raise() ),this,SLOT( raiseWindow() ) ) ;
-	connect( instance,SIGNAL( raiseWithDevice( QString ) ),this,SLOT( raiseWindow( QString ) ) ) ;
+	if( utility::userIsRoot() ){
+
+		utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
+	}
+
+	auto instance = new oneinstance( this,"zuluCrypt-gui.socket","raiseWindow",e ) ;
+
+	if( instance->onlyInstance() ){
+
+		connect( instance,SIGNAL( raise() ),this,SLOT( raiseWindow() ) ) ;
+		connect( instance,SIGNAL( raiseWithDevice( QString ) ),this,SLOT( raiseWindow( QString ) ) ) ;
 
-	if( !instance->instanceExist() ){
 		this->setUpApp( e ) ;
 	}
 }
@@ -292,8 +284,8 @@ void zuluCrypt::setupUIElements()
 
 	QMenu * trayMenu = new QMenu( this ) ;
 
-	trayMenu->addAction( tr( "show the interface" ),this,SLOT( raiseWindow() ) ) ;
-	trayMenu->addAction( tr( "quit" ),this,SLOT( closeApplication() ) ) ;
+	trayMenu->addAction( tr( "Show The Interface" ),this,SLOT( raiseWindow() ) ) ;
+	trayMenu->addAction( tr( "Quit" ),this,SLOT( closeApplication() ) ) ;
 
 	m_trayIcon->setContextMenu( trayMenu ) ;
 
@@ -332,7 +324,6 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->actionAddKey,SIGNAL( triggered() ),this,SLOT( ShowAddKey() ) ) ;
 	connect( m_ui->actionDeleteKey,SIGNAL( triggered() ),this,SLOT( ShowDeleteKey() ) ) ;
 	connect( m_ui->actionPartitionCreate,SIGNAL( triggered() ),this,SLOT( ShowNonSystemPartitions() ) ) ;
-	connect( m_ui->actionInfo,SIGNAL( triggered() ),this,SLOT( info() ) ) ;
 	connect( m_ui->actionFonts,SIGNAL( triggered() ),this,SLOT( fonts() ) ) ;
 	connect( m_ui->menuFavorites,SIGNAL( aboutToShow() ),this,SLOT( readFavorites() ) ) ;
 	connect( m_ui->menuFavorites,SIGNAL( aboutToHide() ),this,SLOT( favAboutToHide() ) ) ;
@@ -345,7 +336,6 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->action_update_volume_list,SIGNAL( triggered() ),this,SLOT( updateVolumeListAction() ) ) ;
 	connect( m_ui->actionMinimize_to_tray,SIGNAL( triggered() ),this,SLOT( minimizeToTray() ) ) ;
 	connect( m_ui->actionClose_all_opened_volumes,SIGNAL( triggered() ),this,SLOT( closeAllVolumes() ) ) ;
-	connect( m_ui->actionPermission_problems,SIGNAL( triggered() ),this,SLOT( permissionExplanation() ) ) ;
 	connect( m_ui->actionEncrypt_file,SIGNAL( triggered() ),this,SLOT( encryptFile() ) ) ;
 	connect( m_ui->actionDecrypt_file,SIGNAL( triggered() ),this,SLOT( decryptFile() ) ) ;
 	connect( m_ui->actionLuks_header_backup,SIGNAL( triggered() ),this,SLOT( HelpLuksHeaderBackUp() ) ) ;
@@ -355,14 +345,16 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->actionManage_volumes_in_kde_wallet,SIGNAL( triggered() ),this,SLOT( manageVolumesInKDEWallet() ) ) ;
 	connect( m_ui->actionManage_volumes_in_gnome_wallet,SIGNAL( triggered() ),this,SLOT( manageVolumesInGNOMEWallet() ) ) ;
 	connect( m_ui->actionManage_volumes_in_internal_wallet,SIGNAL( triggered() ),this,SLOT( manageVolumesInInternalWallet() ) ) ;
+	connect( m_ui->actionOpen_zuluCrypt_pdf,SIGNAL( triggered() ),this,SLOT( openpdf() ) ) ;
 
 	connect( this,SIGNAL( closeVolume( QTableWidgetItem *,int ) ),this,SLOT( closeAll( QTableWidgetItem *,int ) ) ) ;
 
-	m_ui->actionRestore_header->setText( tr( "restore volume header" ) ) ;
-	m_ui->actionBackup_header->setText( tr( "backup volume header" ) ) ;
+	m_ui->actionRestore_header->setText( tr( "Restore Volume Header" ) ) ;
+	m_ui->actionBackup_header->setText( tr( "Backup Volume Header" ) ) ;
 
 	connect( m_ui->actionBackup_header,SIGNAL( triggered() ),this,SLOT( volumeHeaderBackUp() ) ) ;
 	connect( m_ui->actionRestore_header,SIGNAL( triggered() ),this,SLOT( volumeRestoreHeader() ) ) ;
+
 	m_ui->actionManage_volumes_in_gnome_wallet->setEnabled( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::secretServiceBackEnd ) ) ;
 	m_ui->actionManage_volumes_in_kde_wallet->setEnabled( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::kwalletBackEnd ) ) ;
 
@@ -380,7 +372,6 @@ void zuluCrypt::setupConnections()
 	m_ui->actionVeracrypt_container_in_a_partition->setEnabled( false ) ;
 #endif
 
-
 	this->setAcceptDrops( true ) ;
 }
 
@@ -390,6 +381,27 @@ void zuluCrypt::optionMenuAboutToShow()
 	m_ui->actionChange_internal_wallet_password->setEnabled( b ) ;
 }
 
+void zuluCrypt::openpdf()
+{
+	bool failed = Task::await< bool >( [ this ](){ return utility::Task( m_openPath + PDF_PATH ).failed() ; } ) ;
+
+	if( failed ){
+
+		DialogMsg msg( this ) ;
+
+		msg.ShowUIOK( tr( "WARNING!" ),tr( "Failed to open zuluCrypt.pdf,make sure your system can open pdf files using \"%1\" tool and try again" ).arg( m_openPath ) ) ;
+	}
+}
+
+void zuluCrypt::info()
+{
+	QString e = QDir::homePath() + "/.zuluCrypt/doNotshowWarning.option" ;
+
+	auto info = new cryptoinfo( this,e,QString() ) ;
+
+	info->Show() ;
+}
+
 walletconfig * zuluCrypt::setUpWalletConfig()
 {
 	walletconfig * cfg = new walletconfig( this ) ;
@@ -434,12 +446,13 @@ void zuluCrypt::walletpassWordChanged( bool b )
 {
 	Q_UNUSED( b ) ;
 	m_wallet->deleteLater() ;
+	m_wallet = nullptr ;
 }
 
 void zuluCrypt::permissionExplanation()
 {
 	DialogMsg m( this ) ;
-	m.ShowPermissionProblem( QString( "" ) ) ;
+	m.ShowPermissionProblem( QString() ) ;
 }
 
 void zuluCrypt::ShowManageSystemPartitions()
@@ -498,7 +511,7 @@ void zuluCrypt::closeAllVolumes()
 {
 	m_ui->tableWidget->setEnabled( false ) ;
 
-	Task::run( [ this ](){
+	Task::await( [ this ](){
 
 		utility::Task::waitForOneSecond() ; // for ui effect
 
@@ -515,18 +528,25 @@ void zuluCrypt::closeAllVolumes()
 				*( it + i ) = table->item( i,0 ) ;
 			}
 
-			for( QTableWidgetItem * it : tableItems ){
-				QString device = it->text().replace( "\"","\"\"\"" ) ;
-				auto r = utility::Task( QString( "%1 -q -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt ).arg( device ) ) ;
-				emit closeVolume( it,r.exitCode() ) ;
+			QString exe = utility::appendUserUID( "%1 -q -d \"%2\"" ) ;
+
+			for( int i = tableItems.count() - 1 ; i >= 0 ; i-- ){
+
+				QTableWidgetItem * e = *( it + i ) ;
+
+				QString device = e->text().replace( "\"","\"\"\"" ) ;
+
+				auto r = utility::Task( exe.arg( ZULUCRYPTzuluCrypt,device ) ) ;
+
+				emit closeVolume( e,r.exitCode() ) ;
+
 				utility::Task::waitForOneSecond() ; ; // for ui effect
 			}
 		}
 
-	} ).then( [ this ](){
-
-		m_ui->tableWidget->setEnabled( true ) ;
 	} ) ;
+
+	m_ui->tableWidget->setEnabled( true ) ;
 }
 
 void zuluCrypt::closeAll( QTableWidgetItem * item,int st )
@@ -601,7 +621,7 @@ void zuluCrypt::trayClicked( QSystemTrayIcon::ActivationReason e )
 void zuluCrypt::trayProperty()
 {
 	m_ui->actionTray_icon->setEnabled( false ) ;
-	QFile f( QDir::homePath() + QString( "/.zuluCrypt/tray" ) ) ;
+	QFile f( QDir::homePath() + "/.zuluCrypt/tray" ) ;
 	f.open( QIODevice::ReadOnly ) ;
 	QByteArray c = f.readAll() ;
 	f.close() ;
@@ -625,12 +645,12 @@ void zuluCrypt::fonts()
 	int size = 11 ;
 	bool ok ;
 	QFont Font = QFontDialog::getFont( &ok,this->font(),this ) ;
-	if( ok == true ){
+	if( ok ){
 		int k = Font.pointSize() ;
 		if( k > size ){
 			k = size ;
 			Font.setPointSize( k ) ;
-			UIMessage( tr( "info" ),tr( "resetting font size to %1 because larger font sizes do not fit" ).arg( QString::number( size ) ) ) ;
+			UIMessage( tr( "INFO" ),tr( "Resetting font size to %1 because larger font sizes do not fit" ).arg( QString::number( size ) ) ) ;
 		}
 
 		this->setUserFont( Font ) ;
@@ -677,13 +697,9 @@ void zuluCrypt::setUserFont( QFont Font )
 	m_ui->actionManage_volumes_in_kde_wallet->setFont( Font ) ;
 	m_ui->actionUse_kde_default_wallet->setFont( Font ) ;
 	m_ui->actionChange_internal_wallet_password->setFont( Font ) ;
-}
-
-void zuluCrypt::info()
-{
-	cryptoinfo * cinfo = new cryptoinfo( this ) ;
-	connect( cinfo,SIGNAL( closeUISignal() ),cinfo,SLOT( deleteLater() ) ) ;
-	cinfo->show() ;
+	m_ui->actionVeracrypt_container_in_a_file->setFont( Font ) ;
+	m_ui->actionVeracrypt_container_in_a_partition->setFont( Font ) ;
+	m_ui->actionOpen_zuluCrypt_pdf->setFont( Font ) ;
 }
 
 void zuluCrypt::createEncryptedpartitionUI()
@@ -698,17 +714,16 @@ void zuluCrypt::aboutMenuOption( void )
 
 void zuluCrypt::HelpLuksHeaderBackUp()
 {
-	QString msg = tr( "\nAll luks based encrypted volumes have what is called a \"luks header\".\n\n\
-A luks header is responsible for storing information necessary to open a luks based volume and any damage \
+	QString msg = tr( "\nLUKS,TrueCrypt and VeraCrypt based encrypted volumes have what is called a \"volume header\".\n\n\
+A volume header is responsible for storing information necessary to open a header using encrypted volume and any damage \
 to it will makes it impossible to open the volume causing permanent loss of encrypted data.\n\n\
 The damage to the header is usually caused by accidental formatting of the device or use of \
 some buggy partitioning tools or wrongly reassembled logical volumes.\n\n\
-Having a backup of the luks header is strongly advised because it is the only way the encrypted data will be accessible \
-again after the header is restored if the header on the volume get corrupted.\n\n\
-For more information, please read the FAQ at: http://code.google.com/p/cryptsetup/wiki/FrequentlyAskedQuestions" ) ;
+Having a backup of the volume header is strongly advised because it is the only way the encrypted data will be accessible \
+again after the header is restored if the header on the volume get corrupted.\n\n" ) ;
 
 	DialogMsg m( this ) ;
-	m.ShowUIInfo( tr( "important information on luks header" ),msg ) ;
+	m.ShowUIInfo( tr( "Important Information On Volume Header Backup" ),msg ) ;
 }
 
 void zuluCrypt::removeRowFromTable( int x )
@@ -727,11 +742,14 @@ void zuluCrypt::volume_property()
 
 	Task::run<QString>( [ x ](){
 
-		auto r = utility::Task( QString( "%1 -s -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt ).arg( x ) ) ;
+		QString e = utility::appendUserUID( "%1 -s -d \"%2\"" ) ;
+
+		auto r = utility::Task( e.arg( ZULUCRYPTzuluCrypt,x ) ) ;
 
 		if( r.success() ){
 
 			QByteArray data = r.output() ;
+
 			return QString( " %1" ).arg( QString( data.mid( data.indexOf( '\n' ) + 2 ) ) ) ;
 		}else{
 			return QString() ;
@@ -740,11 +758,14 @@ void zuluCrypt::volume_property()
 	} ).then( [ this ]( const QString& r ){
 
 		DialogMsg msg( this ) ;
+
 		if( r.isEmpty() ){
-			msg.ShowUIOK( tr( "ERROR!"),tr( "volume is not open or was opened by a different user" ) ) ;
+
+			msg.ShowUIOK( tr( "ERROR!"),tr( "Volume is not open or was opened by a different user" ) ) ;
 		}else{
-			msg.ShowUIVolumeProperties( tr( "volume properties" ),r ) ;
+			msg.ShowUIVolumeProperties( tr( "Volume Properties" ),r ) ;
 		}
+
 		m_ui->tableWidget->setEnabled( true ) ;
 	} ) ;
 }
@@ -771,7 +792,7 @@ void zuluCrypt::readFavorites()
 			m_ui->menuFavorites->addAction( ac ) ;
 		}
 	}else{
-		ac = new QAction( tr( "list is empty" ),m_ui->menuFavorites ) ;
+		ac = new QAction( tr( "List Is Empty" ),m_ui->menuFavorites ) ;
 		ac->setEnabled( false ) ;
 		m_ui->menuFavorites->addAction( ac ) ;
 	}
@@ -799,12 +820,12 @@ void zuluCrypt::openFolder()
 
 void zuluCrypt::openFolder( QString path )
 {
-	utility::openMountPoint( path,m_folderOpener ).then( [ this ]( bool failed ){
+	utility::openMountPoint( path,m_openPath ).then( [ this ]( bool failed ){
 
 		if( failed ){
 
 			DialogMsg msg( this ) ;
-			msg.ShowUIOK( tr( "warning" ),tr( "could not open mount point because \"%1\" tool does not appear to be working correctly").arg( m_folderOpener ) ) ;
+			msg.ShowUIOK( tr( "WARNING!" ),tr( "Could not open mount point because \"%1\" tool does not appear to be working correctly").arg( m_openPath ) ) ;
 		}
 	} ) ;
 }
@@ -818,29 +839,29 @@ void zuluCrypt::itemClicked( QTableWidgetItem * item,bool clicked )
 {
 	QMenu m ;
 	m.setFont( this->font() ) ;
-	connect( m.addAction( tr( "close" ) ),SIGNAL( triggered() ),this,SLOT( close() ) ) ;
+	connect( m.addAction( tr( "Close" ) ),SIGNAL( triggered() ),this,SLOT( close() ) ) ;
 
 	m.addSeparator() ;
 
-	connect( m.addAction( tr( "properties" ) ) ,SIGNAL( triggered() ),this,SLOT( volume_property() ) ) ;
+	connect( m.addAction( tr( "Properties" ) ) ,SIGNAL( triggered() ),this,SLOT( volume_property() ) ) ;
 
 	m.addSeparator() ;
 
-	connect( m.addAction( tr( "open folder" ) ) ,SIGNAL( triggered() ),this,SLOT( openFolder() ) ) ;
+	connect( m.addAction( tr( "Open Folder" ) ) ,SIGNAL( triggered() ),this,SLOT( openFolder() ) ) ;
 
 	m.addSeparator() ;
 
-	if( m_ui->tableWidget->item( item->row(),2 )->text() == QString( "luks" ) ){
+	if( m_ui->tableWidget->item( item->row(),2 )->text() == "luks" ){
 		m.addSeparator() ;
-		connect( m.addAction( tr( "add key" ) ),SIGNAL( triggered() ),this,SLOT( luksAddKeyContextMenu() ) ) ;
-		connect( m.addAction( tr( "remove key" ) ),SIGNAL( triggered() ),this,SLOT( luksDeleteKeyContextMenu() ) ) ;
+		connect( m.addAction( tr( "Add Key" ) ),SIGNAL( triggered() ),this,SLOT( luksAddKeyContextMenu() ) ) ;
+		connect( m.addAction( tr( "Remove Key" ) ),SIGNAL( triggered() ),this,SLOT( luksDeleteKeyContextMenu() ) ) ;
 		m.addSeparator() ;
-		connect( m.addAction( tr( "backup luks header" ) ),SIGNAL( triggered() ),this,SLOT( luksHeaderBackUpContextMenu() ) ) ;
+		connect( m.addAction( tr( "Backup LUKS Header" ) ),SIGNAL( triggered() ),this,SLOT( luksHeaderBackUpContextMenu() ) ) ;
 	}
 
 	m.addSeparator() ;
 
-	QString volume_id = m_ui->tableWidget->item( item->row(),0 )->text() + QString( "\t" ) ;
+	QString volume_id = m_ui->tableWidget->item( item->row(),0 )->text() + "\t" ;
 
 	QFile f( QDir::homePath() + "/.zuluCrypt/favorites" ) ;
 
@@ -848,7 +869,7 @@ void zuluCrypt::itemClicked( QTableWidgetItem * item,bool clicked )
 
 	QByteArray data = f.readAll() ;
 
-	QAction * ac = m.addAction( tr( "add to favorite" ) ) ;
+	QAction * ac = m.addAction( tr( "Add To Favorite" ) ) ;
 
 	if( data.contains( volume_id.toLatin1() ) ){
 		ac->setEnabled( false ) ;
@@ -863,7 +884,7 @@ void zuluCrypt::itemClicked( QTableWidgetItem * item,bool clicked )
 		int y = m_ui->tableWidget->rowHeight( item->row() ) * item->row() + 20 ;
 
 		m.addSeparator() ;
-		m.addAction( tr( "cancel" ) ) ;
+		m.addAction( tr( "Cancel" ) ) ;
 		m.exec( m_ui->tableWidget->mapToGlobal( QPoint( x,y ) ) ) ;
 	}
 }
@@ -905,40 +926,39 @@ void zuluCrypt::closeStatus( int st )
 void zuluCrypt::closeStatusErrorMessage( int st )
 {
 	switch ( st ) {
-		case 1 :UIMessage( tr( "ERROR!" ),tr( "close failed, volume is not open or was opened by a different user" ) ) ;			break ;
-		case 2 :UIMessage( tr( "ERROR!" ),tr( "close failed, one or more files in the volume are in use." ) ) ;					break ;
-		case 3 :UIMessage( tr( "ERROR!" ),tr( "close failed, volume does not have an entry in /etc/mtab" ) ) ;					break ;
-		case 4 :UIMessage( tr( "ERROR!" ),tr( "close failed, could not get a lock on /etc/mtab~" ) ) ;						break ;
-		case 5 :UIMessage( tr( "ERROR!" ),tr( "close failed, volume is unmounted but could not close mapper,advice to close it manually" ) ) ;	break ;
-		case 6 :UIMessage( tr( "ERROR!" ),tr( "close failed, could not resolve full path of device\n" ) ) ;               			break ;
-		case 7 :UIMessage( tr( "ERROR!" ),tr( "close failed, shared mount point appear to be busy\n" ) ) ;					break ;
-		case 8 :UIMessage( tr( "ERROR!" ),tr( "close failed, shared mount point appear to belong to a different user\n" ) ) ;			break ;
-		case 9 :UIMessage( tr( "ERROR!" ),tr( "close failed, shared mount point appear to be in an ambiguous state,advice to unmount manually" )) ;break ;
-		case 110:UIMessage( tr( "ERROR!" ),tr( "close failed, could not find any partition with the presented UUID" ) ) ;			break ;
-		default:UIMessage( tr( "ERROR!" ),tr( "unrecognized error with status number %1 encountered" ).arg( st ) ) ;
+		case 1 :UIMessage( tr( "ERROR!" ),tr( "Close failed, volume is not open or was opened by a different user" ) ) ;			break ;
+		case 2 :UIMessage( tr( "ERROR!" ),tr( "Close failed, one or more files in the volume are in use." ) ) ;					break ;
+		case 3 :UIMessage( tr( "ERROR!" ),tr( "Close failed, volume does not have an entry in /etc/mtab" ) ) ;					break ;
+		case 4 :UIMessage( tr( "ERROR!" ),tr( "Close failed, could not get a lock on /etc/mtab~" ) ) ;						break ;
+		case 5 :UIMessage( tr( "ERROR!" ),tr( "Close failed, volume is unmounted but could not close mapper,advice to close it manually" ) ) ;	break ;
+		case 6 :UIMessage( tr( "ERROR!" ),tr( "Close failed, could not resolve full path of device\n" ) ) ;               			break ;
+		case 7 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to be busy\n" ) ) ;					break ;
+		case 8 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to belong to a different user\n" ) ) ;			break ;
+		case 9 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to be in an ambiguous state,advice to unmount manually" )) ;break ;
+		case 110:UIMessage( tr( "ERROR!" ),tr( "Close failed, could not find any partition with the presented UUID" ) ) ;			break ;
+		default:UIMessage( tr( "ERROR!" ),tr( "Unrecognized error with status number %1 encountered" ).arg( st ) ) ;
 	}
 }
 
 void zuluCrypt::close()
 {
-	QTableWidgetItem * item = m_ui->tableWidget->currentItem() ;
-
-	QString path = m_ui->tableWidget->item( item->row(),0 )->text().replace( "\"","\"\"\"" ) ;
-
-	QString exe = QString( "%1 -q -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,path ) ;
-
 	m_ui->tableWidget->setEnabled( false ) ;
 
-	Task::run<int>( [ exe ](){
+	int r = Task::await<int>( [ this ](){
+
+		QTableWidgetItem * item = m_ui->tableWidget->currentItem() ;
+
+		QString path = m_ui->tableWidget->item( item->row(),0 )->text().replace( "\"","\"\"\"" ) ;
+
+		QString exe = utility::appendUserUID( "%1 -q -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,path ) ;
 
 		utility::Task::waitForOneSecond() ; //for UI effect
 		return utility::Task( exe ).exitCode() ;
 
-	} ).then( [ this ]( int r ){
-
-		this->closeStatus( r ) ;
-		m_ui->tableWidget->setEnabled( true ) ;
 	} ) ;
+
+	this->closeStatus( r ) ;
+	m_ui->tableWidget->setEnabled( true ) ;
 }
 
 managevolumeheader * zuluCrypt::setUpManageVolumeHeader()
@@ -1025,7 +1045,7 @@ createvolume * zuluCrypt::setUpCreatepartition()
 {
 	createvolume * cp = new createvolume( this ) ;
 	connect( cp,SIGNAL( HideUISignal() ),cp,SLOT( deleteLater() ) ) ;
-	return cp;
+	return cp ;
 }
 
 void zuluCrypt::createPartition( QString partition )
