@@ -41,13 +41,12 @@ static int _mount_get_opts( int argc,char * argv[],ARGS * args )
 	int c ;
 	int k = 0 ;
 
-	while( ( c = getopt( argc,argv,"cEMLntASNshlPmuDd:z:e:Y:p:f:G:o:F:" ) ) != -1 ) {
+	while( ( c = getopt( argc,argv,"cEMLnASNshlPmuDd:z:e:Y:p:f:G:o:F:t:B:b:K:" ) ) != -1 ) {
 		switch( c ){
 			case 'M' : args->share   = 1      ; break ;
 			case 'n' : args->mpo     = 1      ; break ;
 			case 'E' : args->action  = "-E"   ; break ;
 			case 'D' : args->action  = "-D"   ; break ;
-			case 't' : args->action  = "-t"   ; break ;
 			case 's' : args->action  = "-s"   ; break ;
 			case 'l' : args->action  = "-l"   ; break ;
 			case 'L' : args->action  = "-L"   ; break ;
@@ -58,10 +57,16 @@ static int _mount_get_opts( int argc,char * argv[],ARGS * args )
 			case 'm' : args->action  = "-m"   ; break ;
 			case 'u' : args->action  = "-u"   ; break ;
 			case 'c' : args->action  = "-c"   ; break ;
+			case 'B' : args->action  = "-B"   ;
+			           args->m_point = optarg ; break ;
+			case 'b' : args->action  = "-b"   ;
+				   args->m_point = optarg ; break ;
+			case 't' : args->type    = optarg ; break ;
 			case 'o' : args->offset  = optarg ; break ;
 			case 'd' : args->device  = optarg ; break ;
 			case 'z' : args->m_point = optarg ; break ;
 			case 'e' : args->m_opts  = optarg ; break ;
+			case 'K' : args->u_id    = optarg ; break ;
 			case 'Y' : args->fs_opts = optarg ; break ;
 			case 'p' : args->key     = optarg ;
 				   args->key_source = "-p"; break ;
@@ -163,7 +168,7 @@ static int _zuluPartitionHasCryptoFs( const char * device )
 	*/
 	zuluCryptSecurityGainElevatedPrivileges() ;
 	/*
-	 * zuluCryptGetFileSystemFromDevice() is defined in ../zuluCrypt-cli/lib/mount_volume.c
+	 * zuluCryptGetFileSystemFromDevice() is defined in ../zuluCrypt-cli/lib/blkid_evaluate_tag.c
 	 */
 	fs = zuluCryptGetFileSystemFromDevice( device ) ;
 	/*
@@ -207,7 +212,7 @@ static int _zuluMountPrintVolumeDeviceName( const char * device )
 		return 1 ;
 	}else{
 		printf( "%s\n",c ) ;
-		free( c ) ;
+		StringFree( c ) ;
 		return 0 ;
 	}
 }
@@ -271,7 +276,7 @@ static int _checkUnmount( const char * device,uid_t uid )
 				if( zuluCryptUnmountVolume( device,&m_point ) == 0 ){
 					if( m_point != NULL ){
 						rmdir( m_point ) ;
-						free( m_point ) ;
+						StringFree( m_point ) ;
 					}
 				}
 				zuluCryptSecurityDropElevatedPrivileges() ;
@@ -300,6 +305,7 @@ static int _zuluMountExe( ARGS * args )
 	const char * offset = args->offset ;
 	size_t       uid    = args->uid    ;
 
+
 	if( StringsAreEqual( action,"-L" ) ){
 		return zuluMountPrintDeviceProperties( device,uuid,uid ) ;
 	}
@@ -371,11 +377,12 @@ options:\n\
 -A -- print a list of all volumes\n\
 -S -- print a list of system volumes\n\
 -N -- print a list of non system volumes\n\
--E -- print a list of mounted volumes\n" ) ;
+-E -- print a list of mounted volumes\n\
+-t -- to unlock a volume as VeraCrypt volume,use \"-t vera\"\n" ) ;
 
 	doc5= gettext( "\
--o -- offset in sectors on where the volume starts in the volume.The volume is assumed to be plain type with this option\n\
-      and the option must be given when -u or -s arguments are used with a volume opened with this option\n\
+-o -- offset in sectors on where the volume starts in the volume.The volume is assumed to be plain type with this option \
+and the option must be given when -u or -s arguments are used with a volume opened with this option\n\
 -F -- path to truecrypt multiple keyfiles.Keyfiles are separated by \":\" character\n\n" ) ;
 
 	doc6= gettext( "\
@@ -391,7 +398,7 @@ mount and encrypted volume with a key \"xyz\" : zuluMount-cli -m -d /dev/sdc2 -p
 
 static void ExitOnMemoryExaustion( void )
 {
-	printf( gettext( "unexpected exiting because you have run out of memory\n" ) ) ;
+	printf( gettext( "Unexpected exiting because you have run out of memory\n" ) ) ;
 	exit( 1 ) ;
 }
 
@@ -401,15 +408,16 @@ static int _zuluMountDoAction( ARGS * args )
 	int fd1 = -1 ;
 	int status ;
 	char * dev = NULL ;
-	const char * msg = gettext( "ERROR: a non supported device encountered,device is missing or permission denied\n\
+	const char * msg = gettext( "ERROR: A non supported device encountered,device is missing or permission denied\n\
 Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The device has LVM or MDRAID signature\n"  ) ;
 	/*
 	 * zuluCryptGetDeviceFileProperties is defined in ../zuluCrypt-lib/file_path_security.c
 	 */
 	switch( zuluCryptGetDeviceFileProperties( args->device,&fd,&fd1,&dev,args->uid ) ){
+
 		case 0 : args->device = dev ;
 			 /*
-			  * zuluCryptDeviceIsSupported() is defined in ../zuluCrypt-cli/bin/partitions.c
+			  * zuluCryptDeviceIsSupported() is defined in ../zuluCrypt-cli/bin/volumes.c
 			  */
 			 if( zuluCryptDeviceIsSupported( dev,args->uid ) ){
 				status = _zuluMountExe( args ) ;
@@ -418,7 +426,7 @@ Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The de
 				status = 224 ;
 			 }
 			 if( dev != NULL ){
-				 free( dev ) ;
+				 StringFree( dev ) ;
 			 }
 			 if( fd1 != -1 ){
 				 close( fd ) ;
@@ -427,10 +435,10 @@ Possible reasons for getting the error are:\n1.Device path is invalid.\n2.The de
 				 close( fd ) ;
 			 }
 			 return status ;
-		case 1 : printf( gettext( "ERROR: devices in /dev/shm path is not suppored\n" ) ) ;	return 220 ;
-		case 2 : printf( gettext( "ERROR: given path is a directory\n" ) ) ;  			return 221 ;
-		case 3 : printf( gettext( "ERROR: a file can have only one hard link\n" ) ) ;		return 222 ;
-		case 4 : printf( gettext( "ERROR: insufficient privilges to access the device\n" ) ) ; 	return 223 ;
+		case 1 : printf( gettext( "ERROR: Devices in /dev/shm path is not suppored\n" ) ) ;	return 220 ;
+		case 2 : printf( gettext( "ERROR: Given path is a directory\n" ) ) ;  			return 221 ;
+		case 3 : printf( gettext( "ERROR: A file can have only one hard link\n" ) ) ;		return 222 ;
+		case 4 : printf( gettext( "ERROR: Insufficient privilges to access the device\n" ) ) ; 	return 223 ;
 		default: printf( "%s",msg ) ; 								return 224 ;
 	}
 }
@@ -448,6 +456,57 @@ static void _forceTerminateOnSeriousError( int sig )
 	exit( 255 ) ;
 }
 
+static int _create_mount_point( const char * label,const char * m_opts,uid_t uid )
+{
+	/*
+	 * zuluCryptCreateMountPoint() is defined in ../zuluCrypt-cli/bin/create_mount_point.c
+	 */
+	string_t st = zuluCryptCreateMountPoint( NULL,label,m_opts,uid ) ;
+
+	int r ;
+
+	if( st != StringVoid ){
+
+		r = 0 ;
+
+		StringDelete( &st ) ;
+	}else{
+		r = 1 ;
+	}
+
+	return r ;
+}
+
+static int _delete_mount_point( const char * m_path,uid_t uid )
+{
+	/*
+	 * zuluCryptGetUserName() is defined in ../zuluCrypt-cli/lib/user_home_path.c
+	 */
+	string_t st = zuluCryptGetUserName( uid ) ;
+
+	const char * e = StringPrepend( st,"/run/media/private/" ) ;
+
+	int r ;
+
+	if( StringPrefixEqual( m_path,e ) ){
+
+		zuluCryptSecurityGainElevatedPrivileges() ;
+
+		r = rmdir( m_path ) ;
+
+		zuluCryptSecurityDropElevatedPrivileges() ;
+
+	}else{
+		zuluCryptSecurityDropElevatedPrivileges() ;
+
+		r = rmdir( m_path ) ;
+	}
+
+	StringDelete( &st ) ;
+
+	return r ;
+}
+
 int main( int argc,char * argv[] )
 {
 	char * action ;
@@ -492,17 +551,27 @@ int main( int argc,char * argv[] )
 
 	memset( &args,'\0',sizeof( args ) ) ;
 
-	args.uid = uid ;
-
 	/*
 	 * setgroups() requires seteuid(0) ;
 	 */
 	seteuid( 0 ) ;
 	if( setgroups( 1,&gid ) != 0 ){
-		_privilegeEvelationError( "ERROR: setgroups() failed" ) ;
+		_privilegeEvelationError( gettext( "ERROR: setgroups() failed" ) ) ;
 	}
 	if( setegid( uid ) != 0 ){
-		_privilegeEvelationError( "ERROR: setegid() failed" ) ;
+		_privilegeEvelationError( gettext( "ERROR: setegid() failed" ) ) ;
+	}
+	if( _mount_get_opts( argc,argv,&args ) != 0 ){
+		return _mount_help() ;
+	}
+
+	i = zuluCryptSecurityConvertUID( uid,args.u_id ) ;
+
+	if( i == -1 ){
+		puts( gettext( "ERROR: user is not root privileged" ) ) ;
+		return 255 ;
+	}else{
+		args.uid = uid = i ;
 	}
 
 	/*
@@ -519,7 +588,7 @@ int main( int argc,char * argv[] )
 
 	/*
 	 * zuluCryptSecuritySetPrivilegeElevationErrorFunction() is defined in ../zuluCrypt-cli/bin/security.c
-	 * _privilegeEvelationError() function will be called when functions that elevate or drop privilges fail
+	 * _privilegeEvelationError() function will be called when functions that elevate or drop privileges fail
 	 */
 	zuluCryptSecuritySetPrivilegeElevationErrorFunction( _privilegeEvelationError ) ;
 
@@ -537,20 +606,25 @@ int main( int argc,char * argv[] )
 	SocketExitOnMemoryExaustion( ExitOnMemoryExaustion ) ;
 	ProcessExitOnMemoryExaustion( ExitOnMemoryExaustion ) ;
 
-	if( _mount_get_opts( argc,argv,&args ) != 0 ){
-		return _mount_help() ;
-	}
-
 	stl = StringListInit() ;
 	/*
 	 * zuluCryptSecuritySanitizeTheEnvironment() is defined in ../zuluCrypt-cli/bin/security.c
 	 */
 	zuluCryptSecuritySanitizeTheEnvironment( global_variable_user_uid,&stx ) ;
 
+	#define _hide( z ) strncpy( ( char * )z,"x",StringLength( *k ) )
+
+	if( args.device != NULL ){
+		k = StringListAssign( stl ) ;
+		*k = String( args.device ) ;
+		_hide( args.device ) ;
+		args.device = StringContent( *k ) ;
+	}
+
 	if( args.key != NULL ){
 		k = StringListAssign( stl ) ;
 		*k = String( args.key ) ;
-		strncpy( ( char * ) args.key,"x",StringLength( *k ) ) ;
+		_hide( args.key ) ;
 		args.key = StringContent( *k ) ;
 	}
 
@@ -558,14 +632,14 @@ int main( int argc,char * argv[] )
 
 		k = StringListAssign( stl ) ;
 		*k = String( args.tcrypt_multiple_keyfiles[ i ] ) ;
-		strncpy( ( char * ) args.tcrypt_multiple_keyfiles[ i ],"x",StringLength( *k ) ) ;
+		_hide( args.tcrypt_multiple_keyfiles[ i ] ) ;
 		args.tcrypt_multiple_keyfiles[ i ] = StringContent( *k ) ;
 	}
 
 	zuluCryptSecurityLockMemory( stl ) ;
 
 	if( args.action == NULL ){
-		return _zuluExit_2( 212,stl,stx,gettext( "ERROR: action not specified" ) ) ;
+		return _zuluExit_2( 212,stl,stx,gettext( "ERROR: Action not specified" ) ) ;
 	}
 	if( StringsAreEqual( args.action,"-E" ) ){
 		return _zuluExit_2(  zuluMountprintAListOfMountedVolumes(),stl,stx,NULL ) ;
@@ -585,6 +659,12 @@ int main( int argc,char * argv[] )
 	if( StringsAreEqual( args.action,"-N" ) ){
 		return _zuluExit_2( _zuluMountNonSystemDeviceList( uid ),stl,stx,NULL ) ;
 	}
+	if( StringsAreEqual( args.action,"-B" ) ){
+		return _zuluExit_2( _create_mount_point( args.m_point,args.m_opts,args.uid ),stl,stx,NULL ) ;
+	}
+	if( StringsAreEqual( args.action,"-b" ) ){
+		return _zuluExit_2( _delete_mount_point( args.m_point,args.uid ),stl,stx,NULL ) ;
+	}
 	if( StringsAreEqual( args.action,"-h" ) ){
 		return _zuluExit_2( _mount_help(),stl,stx,NULL ) ;
 	}
@@ -609,9 +689,9 @@ int main( int argc,char * argv[] )
 			args.uuid = args.device ;
 			args.device = device ;
 			status = _zuluMountDoAction( &args ) ;
-			free( device ) ;
+			StringFree( device ) ;
 		}else{
-			printf( gettext( "could not resolve UUID\n" ) ) ;
+			printf( gettext( "Could not resolve UUID\n" ) ) ;
 			status = 214 ;
 		}
 	}else if( StringPrefixEqual( args.device,"LABEL=" ) ){
@@ -619,9 +699,9 @@ int main( int argc,char * argv[] )
 		if( device != NULL ){
 			args.device = device ;
 			status = _zuluMountDoAction( &args ) ;
-			free( device ) ;
+			StringFree( device ) ;
 		}else{
-			printf( gettext( "could not resolve LABEL\n" ) ) ;
+			printf( gettext( "Could not resolve LABEL\n" ) ) ;
 			status = 215 ;
 		}
 	}else{
