@@ -30,7 +30,8 @@
 
 stringList_t zuluCryptPartitionList( void ) ;
 
-void zuluMountPartitionProperties( const char * dev,const char * UUID,const char * mapper,const char * m_point )
+void zuluMountPartitionProperties( const char * dev,const char * UUID,
+				   const char * mapper,const char * m_point,const char * fs )
 {
 	#define SIZE 64
 
@@ -52,7 +53,7 @@ void zuluMountPartitionProperties( const char * dev,const char * UUID,const char
 	const char * device = NULL ;
 	char * device_1 = NULL ;
 
-	if( StringPrefixEqual( dev,"encfs" ) ){
+	if( StringsAreEqual( fs,"fuse.encfs" ) ){
 
 		if( m_point != NULL ){
 
@@ -76,8 +77,7 @@ void zuluMountPartitionProperties( const char * dev,const char * UUID,const char
 		 * zuluCryptGetALoopDeviceAssociatedWithAnImageFile()
 		 * is defined in ../zuluCrypt-cli/lib/create_loop_device.c
 		 */
-		device_1 = zuluCryptGetALoopDeviceAssociatedWithAnImageFile( dev ) ;
-		device = device_1 ;
+		device = device_1 = zuluCryptGetALoopDeviceAssociatedWithAnImageFile( dev ) ;
 	}
 
 	blkid = blkid_new_probe_from_filename( device ) ;
@@ -213,6 +213,8 @@ static void _print_device_properties( string_t entry,const char * mapper_path,si
 	const char * e ;
 	const char * f ;
 
+	const char * fs ;
+
 	ssize_t index ;
 
 	string_t st = StringVoid ;
@@ -223,6 +225,8 @@ static void _print_device_properties( string_t entry,const char * mapper_path,si
 		return ;
 	}
 
+	fs = StringListContentAtThirdPlace( stx ) ;
+
 	q = StringListContentAtFirstPlace( stx ) ;
 
 	if( StringPrefixMatch( q,mapper_path,mapper_length ) ){
@@ -257,7 +261,7 @@ static void _print_device_properties( string_t entry,const char * mapper_path,si
 			 * it decodes space,tab,new line and backslash characters since they are written differently in "/etc/mtab"
 			 */
 			f = zuluCryptDecodeMountEntry( StringListStringAtSecondPlace( stx ) ) ;
-			zuluMountPartitionProperties( x,e,q,f ) ;
+			zuluMountPartitionProperties( x,e,q,f,fs ) ;
 			StringFree( x ) ;
 			StringDelete( &st ) ;
 		}else{
@@ -269,13 +273,41 @@ static void _print_device_properties( string_t entry,const char * mapper_path,si
 		e = zuluCryptDecodeMountEntry( StringListStringAtFirstPlace( stx ) ) ;
 		f = zuluCryptDecodeMountEntry( StringListStringAtSecondPlace( stx ) ) ;
 
-		zuluMountPartitionProperties( e,NULL,e,f ) ;
+		zuluMountPartitionProperties( e,NULL,e,f,fs ) ;
 	}
 
 	zuluCryptSecurityDropElevatedPrivileges() ;
 	StringListDelete( &stx ) ;
 }
 
+static int _starts_with_digits_only( string_t st )
+{
+	StringIterator it  ;
+	StringIterator end ;
+
+	char e ;
+
+	StringGetIterators( st,&it,&end ) ;
+
+	while( it != end ){
+
+		e = *it ;
+
+		it++ ;
+
+		if( e == ' ' ){
+
+			return 1 ;
+		}
+		if( !( e >= '0' && e <= '9' ) ){
+
+			return 0 ;
+		}
+	}
+
+	return 1 ;
+}
+
 static int _normal_mounted_volume( string_t st )
 {
 	if( StringStartsWithAtLeastOne( st,"/proc","/sys","/dev ",NULL ) ){
@@ -284,7 +316,11 @@ static int _normal_mounted_volume( string_t st )
 	if( StringEqual( st,"/dev" ) ){
 		return 0 ;
 	}
-	if( StringStartsWithAtLeastOne( st,"/","encfs",NULL ) ){
+	if( StringStartsWith( st,"/" ) ){
+		return 1 ;
+	}
+	if( _starts_with_digits_only( st ) )
+	{
 		return 1 ;
 	}
 	return 0 ;
@@ -359,7 +395,7 @@ int zuluMountPrintVolumesProperties( uid_t uid )
 	while( it != end ){
 		e = StringContent( *it ) ;
 		it++ ;
-		zuluMountPartitionProperties( e,NULL,e,NULL ) ;
+		zuluMountPartitionProperties( e,NULL,e,NULL,NULL ) ;
 	}
 
 	StringListMultipleDelete( &stl,&stz,NULL ) ;
@@ -388,7 +424,7 @@ static void  _zuluMountprintAListOfMountedVolumes( string_t st,const char * mapp
 			/*
 			 * volume is probably an encrypted one
 			 */
-			if( StringContains( q,"-NAAN-" ) ){
+			if( StringHasAtLeastOneComponent( q,"-NAAN-","-VERA-",NULL ) ){
 				zuluCryptSecurityGainElevatedPrivileges() ;
 				/*
 				 * zuluCryptVolumeDeviceName() is defined in ../zuluCrypt-cli/lib/status.c
@@ -603,7 +639,7 @@ int zuluMountPrintDeviceProperties( const char * device,const char * UUID,uid_t
 				/*
 				 * volume is not mounted
 				 */
-				zuluMountPartitionProperties( device,NULL,device,NULL ) ;
+				zuluMountPartitionProperties( device,NULL,device,NULL,NULL ) ;
 			}
 		}
 	}
@@ -636,7 +672,7 @@ int zuluMountUnEncryptedVolumeStatus( const char * device )
 
 	StringDelete( &p ) ;
 
-	p = String( "\n type:   \tNil\n cipher:   \tNil\n keysize:   \tNil\n" ) ;
+	p = String( "\n type:   \tNil\n cipher:   \tNil\n keysize:   \tNil\n offset:    \tNil\n" ) ;
 
 	if( StringPrefixEqual( device,"/dev/loop" ) ){
 		/*
@@ -648,14 +684,14 @@ int zuluMountUnEncryptedVolumeStatus( const char * device )
 		 */
 		z = zuluCryptGetLoopDeviceAddress( device ) ;
 		if( e != NULL && z != NULL ){
-			StringMultipleAppend( p," device:   \t",z,"\n loop:   \t",e,"\n offset:    \tNil",NULL ) ;
+			StringMultipleAppend( p," device:   \t",z,"\n loop:   \t",e,NULL ) ;
 		}else{
-			StringMultipleAppend( p," device:   \t","Nil","\n loop:   \t","Nil","\n offset:    \tNil",NULL ) ;
+			StringMultipleAppend( p," device:   \t","Nil","\n loop:   \tNil",NULL ) ;
 		}
 		StringFree( e ) ;
 		StringFree( z ) ;
 	}else{
-		StringMultipleAppend( p," device:   \t",device," \n loop:   \tNil\n offset:    \tNil",NULL ) ;
+		StringMultipleAppend( p," device:   \t",device," \n loop:   \tNil",NULL ) ;
 	}
 
 	if( StringHasAtLeastOneComponent( StringListStringAt( stl,3 ),"ro,",",ro,",",ro",NULL ) ){
@@ -683,7 +719,7 @@ int zuluMountUnEncryptedVolumeStatus( const char * device )
 	if( e != NULL ){
 		q = String( "" ) ;
 		StringReplaceString( p,"\"Nil\"",StringMultipleAppend( q,"\"",e,"\"",NULL ) ) ;
-		free( e ) ;
+		StringFree( e ) ;
 		StringDelete( &q ) ;
 	}
 
@@ -714,7 +750,7 @@ int zuluMountVolumeStatus( const char * device,const char * UUID,uid_t uid )
 				st = zuluCryptEXEVolumeInfo( e,dev,uid ) ;
 				free( dev ) ;
 			}else{
-				printf( gettext( "ERROR: could not get volume properties,volume is not open or was opened by a different user\n" ) ) ;
+				printf( gettext( "ERROR: Could not get volume properties,volume is not open or was opened by a different user\n" ) ) ;
 				st = 1 ;
 			}
 		}else{
@@ -732,9 +768,9 @@ int zuluMountVolumeStatus( const char * device,const char * UUID,uid_t uid )
 			dev = zuluCryptLoopDeviceAddress_1( device ) ;
 			if( dev != NULL ){
 				st = zuluCryptEXEVolumeInfo( e,dev,uid ) ;
-				free( dev ) ;
+				StringFree( dev ) ;
 			}else{
-				printf( gettext( "ERROR: could not get volume properties,volume is not open or was opened by a different user" ) ) ;
+				printf( gettext( "ERROR: Could not get volume properties,volume is not open or was opened by a different user" ) ) ;
 				st = 1 ;
 			}
 		}else{
