@@ -72,12 +72,8 @@ private:
 
 #define Object_raii( x ) Object_raii< decltype( x ) > Object_raii_x( x ) ; Q_UNUSED( Object_raii_x )
 
-MainWindow::MainWindow( int argc,char * argv[],QWidget * parent ) :QWidget( parent ),
-	m_events( 0 ),m_autoMountAction( 0 )
+MainWindow::MainWindow( QWidget * parent ) : QWidget( parent )
 {
-	m_argc = argc ;
-	m_argv = argv ;
-	m_removeAllVolumes = false ;
 }
 
 void MainWindow::setUpApp( const QString& volume )
@@ -90,7 +86,7 @@ void MainWindow::setUpApp( const QString& volume )
 
 	m_ui->tableWidget->setColumnWidth( 0,220 ) ;
 	m_ui->tableWidget->setColumnWidth( 1,320 ) ;
-	m_ui->tableWidget->setColumnWidth( 2,115 ) ;
+	m_ui->tableWidget->setColumnWidth( 2,145 ) ;
 	m_ui->tableWidget->setColumnWidth( 4,87 ) ;
 	m_ui->tableWidget->setColumnWidth( 5,87 ) ;
 	m_ui->tableWidget->hideColumn( 3 ) ;
@@ -114,6 +110,7 @@ void MainWindow::setUpApp( const QString& volume )
 	connect( m_ui->pbupdate,SIGNAL( clicked()),this,SLOT( pbUpdate() ) ) ;
 	connect( m_ui->pbclose,SIGNAL( clicked() ),this,SLOT( pbClose() ) ) ;
 	connect( m_ui->tableWidget,SIGNAL( itemClicked( QTableWidgetItem * ) ),this,SLOT( itemClicked( QTableWidgetItem * ) ) ) ;
+	connect( m_ui->pbunlockencfs,SIGNAL( clicked() ),this,SLOT( unlockencfs() ) ) ;
 
 	connect( this,SIGNAL( unlistVolume( QString ) ),this,SLOT( removeVolume( QString ) ) ) ;
 
@@ -131,7 +128,7 @@ void MainWindow::setUpApp( const QString& volume )
 	m_autoMountAction->setCheckable( true ) ;
 	m_autoMountAction->setChecked( m_autoMount ) ;
 
-	m_autoMountAction->setText( tr( "automount volumes" ) ) ;
+	m_autoMountAction->setText( tr( "Automount Volumes" ) ) ;
 
 	connect( m_autoMountAction,SIGNAL( toggled( bool ) ),this,SLOT( autoMountToggled( bool ) ) ) ;
 
@@ -141,41 +138,41 @@ void MainWindow::setUpApp( const QString& volume )
 	autoOpenFolderOnMount->setCheckable( true ) ;
 	m_autoOpenFolderOnMount = this->autoOpenFolderOnMount() ;
 	autoOpenFolderOnMount->setChecked( m_autoOpenFolderOnMount ) ;
-	autoOpenFolderOnMount->setText( tr( "auto open mount point" ) ) ;
+	autoOpenFolderOnMount->setText( tr( "Auto Open Mount Point" ) ) ;
 	connect( autoOpenFolderOnMount,SIGNAL( toggled( bool ) ),this,SLOT( autoOpenFolderOnMount( bool ) ) ) ;
 
 	trayMenu->addAction( autoOpenFolderOnMount ) ;
 
 	auto ac = new QAction( this ) ;
-	ac->setText( tr( "show the interface" ) ) ;
+	ac->setText( tr( "Show The Interface" ) ) ;
 	connect( ac,SIGNAL( triggered() ),this,SLOT( raiseWindow() ) ) ;
 
 	trayMenu->addAction( ac ) ;
 
 	ac = new QAction( this ) ;
-	ac->setText( tr( "unmount all" ) ) ;
+	ac->setText( tr( "Unmount All" ) ) ;
 	connect( ac,SIGNAL( triggered() ),this,SLOT( unMountAll() ) ) ;
 
 	trayMenu->addAction( ac ) ;
 
-	m_favorite_menu = trayMenu->addMenu( tr( "favorites" ) ) ;
+	m_favorite_menu = trayMenu->addMenu( tr( "Favorites" ) ) ;
 	connect( m_favorite_menu,SIGNAL( triggered( QAction * ) ),this,SLOT( favoriteClicked( QAction * ) ) ) ;
 	connect( m_favorite_menu,SIGNAL( aboutToShow() ),this,SLOT( showFavorites() ) ) ;
 
-	m_not_hidden_volume_menu = trayMenu->addMenu( tr( "hide volume from view" ) ) ;
+	m_not_hidden_volume_menu = trayMenu->addMenu( tr( "Hide Volume From View" ) ) ;
 	connect( m_not_hidden_volume_menu,SIGNAL( triggered( QAction * ) ),this,SLOT( removeVolumeFromVisibleVolumeList( QAction * ) ) ) ;
 	connect( m_not_hidden_volume_menu,SIGNAL( aboutToShow() ),this,SLOT( showVisibleVolumeList() ) ) ;
 
-	m_hidden_volume_menu = trayMenu->addMenu( tr( "unhide volume from view" ) ) ;
+	m_hidden_volume_menu = trayMenu->addMenu( tr( "Unhide Volume From View" ) ) ;
 	connect( m_hidden_volume_menu,SIGNAL( triggered( QAction * ) ),this,SLOT( removeVolumeFromHiddenVolumeList( QAction * ) ) ) ;
 	connect( m_hidden_volume_menu,SIGNAL( aboutToShow() ),this,SLOT( showHiddenVolumeList() ) ) ;
 
 	ac = new QAction( this ) ;
-	ac->setText( tr( "about" ) ) ;
+	ac->setText( tr( "About" ) ) ;
 	connect( ac,SIGNAL( triggered() ),this,SLOT( licenseInfo() ) ) ;
 	trayMenu->addAction( ac ) ;
 
-	trayMenu->addAction( tr( "quit" ),this,SLOT( pbClose() ) ) ;
+	trayMenu->addAction( tr( "Quit" ),this,SLOT( pbClose() ) ) ;
 	m_trayIcon->setContextMenu( trayMenu ) ;
 
 	connect( m_trayIcon,SIGNAL( activated( QSystemTrayIcon::ActivationReason ) ),
@@ -183,7 +180,7 @@ void MainWindow::setUpApp( const QString& volume )
 
 	m_trayIcon->show() ;
 
-	QString dirPath = QDir::homePath() + "/.zuluCrypt/" ;
+	QString dirPath = utility::homePath() + "/.zuluCrypt/" ;
 	QDir dir( dirPath ) ;
 
 	if( !dir.exists() ){
@@ -229,7 +226,7 @@ void MainWindow::showHiddenVolumeList()
 
 	if( l.isEmpty() ){
 
-		auto ac = new QAction( tr( "list is empty" ),m_hidden_volume_menu ) ;
+		auto ac = new QAction( tr( "List Is Empty" ),m_hidden_volume_menu ) ;
 		ac->setEnabled( false ) ;
 		m_hidden_volume_menu->addAction( ac ) ;
 	}else{
@@ -248,7 +245,7 @@ void MainWindow::showVisibleVolumeList()
 
 	if( l.isEmpty() ){
 
-		auto ac = new QAction( tr( "list is empty" ),m_not_hidden_volume_menu ) ;
+		auto ac = new QAction( tr( "List Is Empty" ),m_not_hidden_volume_menu ) ;
 		ac->setEnabled( false ) ;
 		m_not_hidden_volume_menu->addAction( ac ) ;
 	}else{
@@ -288,7 +285,7 @@ void MainWindow::showFavorites()
 	QStringList l = utility::readFavorites() ;
 
 	if( l.isEmpty() ){
-		auto ac = new QAction( tr( "list is empty" ),m_favorite_menu ) ;
+		auto ac = new QAction( tr( "List Is Empty" ),m_favorite_menu ) ;
 		ac->setEnabled( false ) ;
 		m_favorite_menu->addAction( ac ) ;
 	}else{
@@ -303,20 +300,17 @@ void MainWindow::showFavorites()
 void MainWindow::setLocalizationLanguage()
 {
 	auto translator  = new QTranslator( this ) ;
-	QString pgr      = "zuluMount-gui" ;
-	QString lang     = utility::localizationLanguage( pgr ) ;
-	QString langPath = utility::localizationLanguagePath( pgr ) ;
 
-	QByteArray r = lang.toLatin1() ;
+	const char * app = "zuluMount-gui" ;
 
-	QByteArray e( "en_US" ) ;
+	QByteArray r = utility::localizationLanguage( app ).toLatin1() ;
 
-	if( e == r ){
+	if( r == "en_US" ){
 		/*
 		 * english_US language,its the default and hence dont load anything
 		 */
 	}else{
-		translator->load( r.constData(),langPath ) ;
+		translator->load( r.constData(),utility::localizationLanguagePath( app ) ) ;
 		QCoreApplication::installTranslator( translator ) ;
 	}
 }
@@ -325,7 +319,7 @@ void MainWindow::setLocalizationLanguage()
 
 void MainWindow::autoOpenFolderOnMount( bool b )
 {
-	QString x = QDir::homePath() + QString( zuluMOUNT_AUTO_OPEN_FOLDER ) ;
+	QString x = utility::homePath() + zuluMOUNT_AUTO_OPEN_FOLDER ;
 
 	m_autoOpenFolderOnMount = b ;
 	if( b ){
@@ -339,8 +333,8 @@ void MainWindow::autoOpenFolderOnMount( bool b )
 
 bool MainWindow::autoOpenFolderOnMount( void )
 {
-	QString x = QDir::homePath() + QString( zuluMOUNT_AUTO_OPEN_FOLDER ) ;
-	return QFile::exists( x ) == false ;
+	QString x = utility::homePath() + zuluMOUNT_AUTO_OPEN_FOLDER ;
+	return !QFile::exists( x ) ;
 }
 
 void MainWindow::startAutoMonitor()
@@ -496,20 +490,27 @@ void MainWindow::raiseWindow( QString volume )
 	this->showMoungDialog( volume ) ;
 }
 
-void MainWindow::start()
+void MainWindow::Show()
 {
 	QStringList l = QCoreApplication::arguments() ;
 
 	m_startHidden  = l.contains( "-e" ) ;
 	m_folderOpener = utility::cmdArgumentValue( l,"-m","xdg-open" ) ;
 
+	if( utility::userIsRoot() ){
+
+		utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
+	}
+
 	QString volume = utility::cmdArgumentValue( l,"-d" ) ;
 
-	QString sockpath = "zuluMount-gui.socket" ;
-	auto instance = new oneinstance( this,sockpath,"startGUI",volume ) ;
-	if( !instance->instanceExist() ){
+	auto instance = new oneinstance( this,"zuluMount-gui.socket","startGUI",volume ) ;
+
+	if( instance->onlyInstance() ){
+
 		connect( instance,SIGNAL( raise() ),this,SLOT( raiseWindow() ) ) ;
 		connect( instance,SIGNAL( raiseWithDevice( QString ) ),this,SLOT( raiseWindow( QString ) ) ) ;
+
 		this->setUpApp( volume ) ;
 	}
 }
@@ -528,14 +529,14 @@ void MainWindow::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 
 	if( mt == "Nil" ){
 
-		connect( m.addAction( tr( "mount" ) ),SIGNAL( triggered() ),this,SLOT( slotMount() ) ) ;
+		connect( m.addAction( tr( "Mount" ) ),SIGNAL( triggered() ),this,SLOT( slotMount() ) ) ;
 	}else{
 		QString mp = QString( "/run/media/private/%1/" ).arg( utility::userName() ) ;
 		QString mp_1 = QString( "/home/%1/" ).arg( utility::userName() ) ;
 
 		if( mt.startsWith( mp ) || mt.startsWith( mp_1 ) ){
 
-			connect( m.addAction( tr( "unmount" ) ),SIGNAL( triggered() ),this,SLOT( pbUmount() ) ) ;
+			connect( m.addAction( tr( "Unmount" ) ),SIGNAL( triggered() ),this,SLOT( pbUmount() ) ) ;
 
 			m.addSeparator() ;
 
@@ -543,7 +544,7 @@ void MainWindow::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 
 			if( fs != "encfs" ){
 
-				connect( m.addAction( tr( "properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
+				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
 				m.addSeparator() ;
 			}
 
@@ -551,12 +552,12 @@ void MainWindow::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 
 			if( m_sharedFolderPath.isEmpty() ){
 
-				connect( m.addAction( tr( "open folder" ) ),SIGNAL( triggered() ),
+				connect( m.addAction( tr( "Open Folder" ) ),SIGNAL( triggered() ),
 					 this,SLOT( slotOpenFolder() ) ) ;
 			}else{
-				connect( m.addAction( tr( "open private folder" ) ),SIGNAL( triggered() ),
+				connect( m.addAction( tr( "Open Private Folder" ) ),SIGNAL( triggered() ),
 					 this,SLOT( slotOpenFolder() ) ) ;
-				connect( m.addAction( tr( "open shared folder" ) ),SIGNAL( triggered() ),
+				connect( m.addAction( tr( "Open Shared Folder" ) ),SIGNAL( triggered() ),
 					 this,SLOT( slotOpenSharedFolder() ) ) ;
 			}
 		}else{
@@ -566,26 +567,26 @@ void MainWindow::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 
 				if( utility::pathIsReadable( mt ) ){
 
-					connect( m.addAction( tr( "properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
+					connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
 					m.addSeparator() ;
-					connect( m.addAction( tr( "open folder" ) ),SIGNAL( triggered() ),
+					connect( m.addAction( tr( "Open Folder" ) ),SIGNAL( triggered() ),
 						 this,SLOT( slotOpenFolder() ) ) ;
 				}else{
-					connect( m.addAction( tr( "properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
+					connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
 				}
 			}else{
-				connect( m.addAction( tr( "properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
+				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),this,SLOT( volumeProperties() ) ) ;
 
 				m.addSeparator() ;
 
-				connect( m.addAction( tr( "open shared folder" ) ),SIGNAL( triggered() ),
+				connect( m.addAction( tr( "Open Shared Folder" ) ),SIGNAL( triggered() ),
 					 this,SLOT( slotOpenSharedFolder() ) ) ;
 			}
 		}
 	}
 
 	m.addSeparator() ;
-	m.addAction( tr( "close menu" ) ) ;
+	m.addAction( tr( "Close Menu" ) ) ;
 
 	if( itemClicked ){
 		m.exec( QCursor::pos() ) ;
@@ -631,12 +632,12 @@ void MainWindow::slotOpenFolder()
 
 void MainWindow::openMountPoint( const QString& m_point )
 {
-	utility::openMountPoint( m_point,m_folderOpener ).then( [ this ]( bool failed ){
+	utility::openMountPoint( m_point,m_folderOpener,m_env ).then( [ this ]( bool failed ){
 
 		if( failed ){
-			QString x = tr( "could not open mount point because \"%1\" tool does not appear to be working correctly").arg( m_folderOpener ) ;
+			QString x = tr( "Could not open mount point because \"%1\" tool does not appear to be working correctly").arg( m_folderOpener ) ;
 			DialogMsg msg( this ) ;
-			msg.ShowUIOK( tr( "warning" ),x ) ;
+			msg.ShowUIOK( tr( "Warning" ),x ) ;
 		}
 	} ) ;
 }
@@ -662,14 +663,14 @@ void MainWindow::volumeProperties()
 
 	if( r.isEmpty() ){
 		msg.ShowUIOK( tr( "ERROR" ),
-			      tr( "could not get volume properties.\nvolume is not open or was opened by a different user" ) ) ;
+			      tr( "Could not get volume properties.\nvolume is not open or was opened by a different user" ) ) ;
 	}else{
 		int i = r.indexOf( "\n" ) ;
 		if( i != -1 ){
-			msg.ShowUIVolumeProperties( tr( "volume properties" ),r.mid( i + 1 ) ) ;
+			msg.ShowUIVolumeProperties( tr( "Volume Properties" ),r.mid( i + 1 ) ) ;
 		}else{
 			msg.ShowUIOK( tr( "ERROR" ),
-				      tr( "could not get volume properties.\nvolume is not open or was opened by a different user" ) ) ;
+				      tr( "Could not get volume properties.\nvolume is not open or was opened by a different user" ) ) ;
 		}
 	}
 
@@ -794,11 +795,11 @@ void MainWindow::slotMount()
 
 void MainWindow::showMoungDialog( const volumeEntryProperties& v )
 {
-	if( v.Empty() ){
+	if( v.isEmpty() ){
 
 		DialogMsg msg( this ) ;
 		msg.ShowUIOK( tr( "ERROR" ),
-			      tr( "permission to access the volume was denied\nor\nthe volume is not supported\n(LVM/MDRAID signatures found)" ) ) ;
+			      tr( "Permission to access the volume was denied\nor\nthe volume is not supported\n(LVM/MDRAID signatures found)" ) ) ;
 		this->enableAll() ;
 	}else{
 		this->mount( v ) ;
@@ -817,16 +818,9 @@ void MainWindow::showMoungDialog( const QString& volume )
 
 			QStringList l ;
 
-			l.append( volume ) ;
-			l.append( "Nil" ) ;
-			l.append( "encfs" ) ;
-			l.append( "Nil" ) ;
-			l.append( "Nil" ) ;
-			l.append( "Nil" ) ;
+			l << volume << "Nil" << "encfs" << "Nil" << "Nil" << "Nil" ;
 
-			volumeEntryProperties v( l ) ;
-
-			this->mount( v ) ;
+			this->mount( volumeEntryProperties( l ) ) ;
 		}
 	}
 }
@@ -835,7 +829,21 @@ void MainWindow::pbMount()
 {
 	this->disableAll() ;
 
-	QString path = QFileDialog::getOpenFileName( this,tr( "select an image file to mount" ),QDir::homePath() ) ;
+	QString path = QFileDialog::getOpenFileName( this,tr( "Select An Image File To Mount" ),utility::homePath() ) ;
+
+	if( path.isEmpty() ){
+
+		this->enableAll() ;
+	}else{
+		this->showMoungDialog( path ) ;
+	}
+}
+
+void MainWindow::unlockencfs()
+{
+	this->disableAll() ;
+
+	QString path = QFileDialog::getExistingDirectory( this,tr( "Select An Encfs Volume Directory" ),utility::homePath(),QFileDialog::ShowDirsOnly ) ;
 
 	if( path.isEmpty() ){
 
@@ -883,6 +891,22 @@ void MainWindow::volumeMiniProperties( volumeEntryProperties * volumeInfo )
 	this->disableAll() ;
 
 	if( volumeInfo ){
+
+		this->updateList( *volumeInfo ) ;
+		this->enableAll() ;
+	}else{
+		this->pbUpdate() ;
+	}
+}
+
+void MainWindow::volumeMiniProperties_0( volumeEntryProperties * volumeInfo )
+{
+	Object_raii( volumeInfo ) ;
+
+	this->disableAll() ;
+
+	if( volumeInfo && volumeInfo->mounted() ){
+
 		this->updateList( *volumeInfo ) ;
 		this->enableAll() ;
 	}else{
@@ -892,7 +916,7 @@ void MainWindow::volumeMiniProperties( volumeEntryProperties * volumeInfo )
 
 void MainWindow::updateList( const volumeEntryProperties& entry )
 {
-	if( entry.notEmpty() ){
+	if( entry.isNotEmpty() ){
 
 		auto table = m_ui->tableWidget ;
 
@@ -925,7 +949,7 @@ void MainWindow::pbUmount()
 		if( !zuluMountTask::encfsUnmount( m ).await() ){
 
 			DialogMsg m( this ) ;
-			m.ShowUIOK( tr( "ERROR" ),tr( "failed to unmount encfs volume" ) ) ;
+			m.ShowUIOK( tr( "ERROR" ),tr( "Failed to unmount encfs volume" ) ) ;
 			this->enableAll() ;
 		}
 	}else{
@@ -980,9 +1004,7 @@ void MainWindow::unMountAll()
 
 			utility::Task::waitForOneSecond() ;
 		}else{
-			int r = p.size() ;
-
-			for( int i = 0 ; i < r ; i++ ){
+			for( int i = p.size() - 1 ; i >= 0 ; i-- ){
 
 				const QString& e = q.at( i ) ;
 
@@ -1020,7 +1042,7 @@ void MainWindow::updateVolumeList( const QVector< volumeEntryProperties >& r )
 
 		DialogMsg msg( this ) ;
 		msg.ShowUIOK( tr( "ERROR" ),
-			      tr( "reading partition properties took longer than expected and operation was terminated,click refresh to try again" ) ) ;
+			      tr( "Reading partition properties took longer than expected and operation was terminated,click refresh to try again" ) ) ;
 
 		this->enableAll() ;
 	}else{
@@ -1055,7 +1077,7 @@ void MainWindow::removeDisappearedEntries( const QVector< volumeEntryProperties
 
 			if( it.volumeName() == volume ){
 
-				if( volume.startsWith( "encfs" ) ){
+				if( it.fileSystem() == "encfs" ){
 
 					return false ;
 				}
@@ -1114,6 +1136,7 @@ void MainWindow::disableAll()
 	m_ui->pbmount->setEnabled( false ) ;
 	m_ui->pbupdate->setEnabled( false ) ;
 	m_ui->tableWidget->setEnabled( false ) ;
+	m_ui->pbunlockencfs->setEnabled( false ) ;
 }
 
 void MainWindow::enableAll()
@@ -1126,6 +1149,7 @@ void MainWindow::enableAll()
 	m_ui->tableWidget->setEnabled( true ) ;
 	m_ui->pbmount->setEnabled( true ) ;
 	m_ui->tableWidget->setFocus() ;
+	m_ui->pbunlockencfs->setEnabled( true ) ;
 }
 
 void MainWindow::enableAll_1()
@@ -1138,13 +1162,13 @@ void MainWindow::enableAll_1()
 
 bool MainWindow::autoMount()
 {
-	QFile f( QDir::homePath() + QString( zuluMOUNT_AUTOPATH ) ) ;
+	QFile f( utility::homePath() + zuluMOUNT_AUTOPATH ) ;
 	return f.exists() ;
 }
 
 MainWindow::~MainWindow()
 {
-	QFile f( QDir::homePath() + QString( zuluMOUNT_AUTOPATH ) ) ;
+	QFile f( utility::homePath() + zuluMOUNT_AUTOPATH ) ;
 
 	if( m_autoMountAction ){
 		if( m_autoMountAction->isChecked() ){
